#ifndef __PCI3009_H__
#define __PCI3009_H__

/** \mainpage xPCI-3009 API functions documentation
* \section intro_sec Introduction
* See the PCI3009.h file to view the functions list \n
* See the DEFINE.h file to view the define list 
*/

 /** @file PCI3009.H
 * Header file of the xPCI-3009 
 * 
 * 
 *  @author S. Weber
 *  @date 25.04.2008
 *  
 *  
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2004,2005  ADDI-DATA GmbH for the source code of this module.
 *       
*      ADDI-DATA GmbH                                                        
*      Airport Boulevard B210
*      D-77836 Rheinmnster
*      Tel: +19(0)7229/1847-0
*      Fax: +49(0)7229/1847-200
*      http:$/$/www.addi-data-com                                            
*      info@addi-data.com                                                    
 *       
 * @endverbatim   
 */

#include <stdio.H>
#include <dos.H>
#include <windows.h>
#include <winioctl.h>
#include <io.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <math.h>

#include "define.h"
#include "PCI3009_define.h"

/** \defgroup PCI3009 PCI-3009 functions
* @{
*/

/* @} */

/** \defgroup PCI3009_INIT PCI-3009 initialisation functions
* \ingroup PCI3009
* @{
*/
/* i_PCI3009_GetDeviceDriverVersion */
/**
 * Gets the version of the device driver.
 *
 * @param[in]   dw_DeviceHandle Handle of the board
 * @param[out]  pdw_Version Version. For example: 0x01011211 -> Version 1.01, December 2011
 * @retval  0   No Error
 * @retval -1   Error while calling IOCTL function
 */
_INT_ i_PCI3009_GetDeviceDriverVersion(IN DWORD_ dw_DeviceHandle, OUT DWORD *pdw_Version);

/* i_PCI3009_GetDLLVersion */
/**
 * Gets the version of the DLL.
 *
 * @param[out]  pdw_Version Version. For example: 0x01010910 -> Version 1.01, September 2010
 * @retval  0   No Error
 */
_INT_ i_PCI3009_GetDLLVersion(OUT DWORD *pdw_Version);

/* i_PCI3009_GetNumberOfBoards */
/**
 * Returns the number of xPCI3009 boards present in the system. \n
 * The function fills the value pointed by pb_NbrOfBoards with the number of boards present.
 *
 * @param[out]  pb_NbrOfBoards Value that will be filled with the number of boards
 * @retval  0   No error
 * @retval -1   Error while getting the number of boards
 */
_INT_ i_PCI3009_GetNumberOfBoards(OUT BYTE *pb_NbrOfBoards);

/* i_PCI3009_OpenBoardViaIndex */
/**
 * Opens the board with the specified index. A handle is returned to the \n
 * user which allows driver functions to be used. \n
 *
 * @param[in]   b_BoardIndex Index of the board to open
 * @param[out]  pdw_BoardHandle Handle of board PCI-3009
 * @retval  0   No error
 * @retval -1   Unable to get the number of available boards
 * @retval -2   Wrong device index parameter, the parameter is too high
 * @retval -3   Error while getting the device's class
 * @retval -4   Error while getting informations about the device
 * @retval -5   Memory allocation error
 * @retval -6   Get device interface detail error
 * @retval -7   Error while creating communication handle
 * @retval -8   Error in the initialization callback function
 */
_INT_ i_PCI3009_OpenBoardViaIndex(IN BYTE b_BoardIndex, OUT DWORD *pdw_BoardHandle);


/*i_PCI3009_OpenBoardViaIdentifer*/
/** Open the selected PCI3009 board
*                                                                      
* @param[in] pc_Identification   : Identification string of the board PCI3009
* @param[out] pdw_BoardHandle     : Handle of board PCI-3009
*
* @retval  0 No error \n
* @retval -1 Not available identifier \n
* @retval -2 Board not present \n
* @retval -3 No handle is available for the board \n
* @retval -4 Can not open the Windows kernel driver \n
* @retval -5 Board I/O access error
*/
_INT_ i_PCI3009_OpenBoardViaIdentifer (PCHAR_   pc_Identification,
				                       PDWORD_ pdw_BoardHandle);


/*i_PCI3009_CheckAndGetPCISlotNumber*/
/** This function gets the slots number and return the number of boards found.
 * @param[in] pdw_SlotNumberArray : Array containing the slots number of the board
 * 
 * @retval 0 No board found
 * @retval >0 Number of boards
 */
_INT_ i_PCI3009_CheckAndGetPCISlotNumber (PDWORD_ pdw_SlotNumberArray);


/*i_PCI3009_OpenBoardViaSlotNumber*/
/** This function opens the board by giving the slot number.
 * @param[in] dw_SlotNumber : Slot number of the board
 * @param[in] pdw_BoardHandle : Handle of board PCI-3009
 * 
 * @retval 0 No error
 * @retval -1 Cannot open the board
 */
_INT_ i_PCI3009_OpenBoardViaSlotNumber   (DWORD_   dw_SlotNumber,
				                          PDWORD_ pdw_BoardHandle);
										  
/* i_PCI3600_GetBoardInformation */
/**
 * Gets generic device information.
 *
 * @param[in]   b_BoardIndex Index of the board
 * @param[in]   dw_IdentifierStringSize Size of the identifier parameter buffer
 * @param[out]  pc_Identifier Identifier of the board
 * @param[out]  pdw_UINumber This number is typically a user-perceived slot number, such as a number printed next to the slot on the board, or some other number that makes locating the physical device easier for the user. If the device is on a bus that has no UI number convention, or if the bus driver for the device cannot determine the UI number, this value is 0xFFFFFFFF.
 * @param[out]  pdw_DeviceNumber Device number.
 * @param[out]  pdw_BusNumber Bus number.
 * @param[out]  pdw_BaseAddress0 Base address 0 of the board
 * @param[out]  pdw_BaseAddress1 Base address 1 of the board
 * @param[out]  pdw_BaseAddress2 Base address 2 of the board
 * @param[out]  pdw_BaseAddress3 Base address 3 of the board
 * @param[out]  pb_Interrupt Interrupt line of the board
 * @param[out]  pdw_ModuleConfiguration Module configuration, can be :
 *                              <ul>    
 *									<li> Module version in 2 ASCII characters (example 0x3132 = 12)
 *										<ul>
 *                                			<li> bits 0-7 second ASCII digit </li>
 *                                      	<li> bits 8-15 first ASCII digit </li>
 *                                      </ul>
 *                              </ul>
 *                              <ul>
 *									<li> Module functionality </li>
 *										<ul>
 *	                                		<li> 0x5343 : Incremental counter </li>
 *  	                              		<li> 0x5349 : SSI </li>
 *      	                          		<li> 0x4449 : Digital IO</li>
 *          	                      		<li> 0x4348 : SSI </li>
 *										</ul>
 *                              </ul>
 *                                
 * @param[out]  pdw_Revision Revision of the board in ASCII
 *                                \li bits 0-7 : fourth character
 *                                \li bits 8-15 : third character
 *                                \li bits 16-23 : second character
 *                                \li bits 24-31 : first character
 * @retval  0   No error
 * @retval -1   Unable to open the board via index
 * @retval -2   Error when calling driver's IOCTL
 */
_INT_ i_PCI3009_GetBoardInformation(IN  BYTE  b_BoardIndex,
                                    IN  DWORD dw_IdentifierStringSize,
                                    OUT CHAR  *pc_Identifier,
                                    OUT DWORD *pdw_UINumber,
                                    OUT DWORD *pdw_DeviceNumber,
                                    OUT DWORD *pdw_BusNumber,
                                    OUT DWORD *pdw_BaseAddress0,
                                    OUT DWORD *pdw_BaseAddress1,
                                    OUT DWORD *pdw_BaseAddress2,
                                    OUT DWORD *pdw_BaseAddress3,
                                    OUT BYTE  *pb_Interrupt,
									OUT DWORD *pdw_ModuleConfiguration,
									OUT DWORD *pdw_Revision);
									
/*i_PCI3009_SetBoardIntRoutine*/
/** This function must be called up for each xPCI-3009 on which an interrupt action is to be enabled. \n
*
* <b>IMPORTANT: i_PCI3009_SetBoardIntRoutineNew function has to be used instead of i_PCI3009_SetBoardIntRoutine.
* i_PCI3009_SetBoardIntRoutine is implemented for backward compatibility reason.</b> \n
*
* It installs an user interrupt function in all boards on which an interrupt is to be enabled. \n
* First calling (first board): \n
*    - the user interrupt routine is installed \n
*    - interrupts are enabled. \n
* If you operate several boards xPCI-3009 which have to react to interrupts, call up the function as often \n
* as you operate boards xPCI-3009. \n
* The variables v_FunctionName and dw_UserCallingMode is only relevant for the first calling.\n
* From the second call of the function (next board): \n
* \- Interrupts are enabled. The first board can receive IRQ. \n\n
*
* The user interrupt routine must have the following Syntax: \n
* void WINAPI v_FunctionName (DWORD_   dw_BoardHandle,\n
*                             DWORD_   dw_InterruptSrc, \n
*                             DWORD_   dw_InterruptMask, \n
*                             PDWORD_ pdw_Value, \n
*                             DWORD_   dw_UserCallingMode, \n
*                             VOID *   pv_UserSharedMemory) </b>\n\n
* <b>v_FunctionName</b>   Name of the user interrupt routine \n
* <b>dw_BoardHandle</b>   Handle of the xPCI-3009 which has generated the interrupt \n
* <b>dw_InterruptSrc</b>  Interrupt source (0: Analog input / 1: Incremental counter) \n
* <b>dw_InterruptMask</b> Mask of the events which have generated the interrupt. \n
* <b>pdw_Value</b>        Interrupt value \n\n
*
* <table>
*    <tr>
*       <td>dw_InterruptSrc</td>
*       <td>dw_InterruptMask</td>
*       <td>Meaning / pdw_Value</td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>1Hex</td>
*       <td>
*          Single acquisition interrupt (i_PCI3009_AnalogInputRead1Channel or i_PCI3009_AnalogInputReadMoreChannels) \n
*          pdw_Value[0] : Number of acquisitions \n
*          pdw_Value[1] : First channel value \n
*          ... \n
*          pdw_Value[pdw_Value [0] - 1] : Last channel value
*       </td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>2Hex</td>
*       <td>
*          Sequence acquisition interrupt without DMA (i_PCI3009_AnalogInputStartSequence) \n
*          pdw_Value[0] : Number of acquisitions (Sequence size) \n
*          pdw_Value[1] : First sequence channel value \n
*          ... \n
*          pdw_Value [pdw_Value [0] - 1] : Last sequence channel value
*       </td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>4Hex</td>
*       <td>
*          Sequence acquisition interrupt with DMA (i_PCI3009_AnalogInputStartSequence) \n
*          pdw_Value[0] = Number of buffer \n
*          pdw_Value[1] = Number of digital values for the buffer 0 \n
*          pdw_Value[2] = Buffer 0 ring 0 address \n
*          pdw_Value[3] = Buffer 0 ring 3 address \n
*          pdw_Value[4] = Number of digital values for the buffer 1 \n
*          pdw_Value[5] = Buffer 1 ring 0 address \n
*          pdw_Value[6] = Buffer 1 ring 3 address \n
*          ...
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>1Hex</td>
*       <td>
*          Hardware latch of the 1. register (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10001Hex</td>
*       <td>
*          Hardware latch of the 1. register (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>2Hex</td>
*       <td>
*          Hardware latch of the 2. register (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10002Hex</td>
*       <td>
*          Hardware latch of the 2. register (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>4Hex</td>
*       <td>
*          Index interrupt (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10004Hex</td>
*       <td>
*          Index interrupt (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>8Hex</td>
*       <td>Compare interrupt</td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10Hex</td>
*       <td>
*          Interrupt at the end of frequency measurement \n
*          pdw_Value[0] = Measured value
*    </tr>
*    <tr>
*       <td>2 (Chronos)</td>
*       <td>1Hex</td>
*       <td>
*          Interrupt at the end of chronos measurement \n
*          pdw_Value[0] = Measured value
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>1Hex</td>
*       <td>
*          Timer 0 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>2Hex</td>
*       <td>
*          Counter 0 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>8Hex</td>
*       <td>
*          Timer 1 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>10Hex</td>
*       <td>
*          Counter 1 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>20Hex</td>
*       <td>
*          Watchdog 1 (analog output) run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>40Hex</td>
*       <td>
*          Timer 2 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>80Hex</td>
*       <td>
*          Counter 2 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>100Hex</td>
*       <td>
*          Watchdog 2 (digital output) run down
*       </td>
*    </tr>
*    <tr>
*       <td>5 (FIFO information)</td>
*       <td>1Hex</td>
*       <td>
*          Driver interrupt FIFO overflow
*       </td>
*    </tr>*
* </table> \n
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] dw_UserCallingMode  : Always set on PCI3009_ASYNCHRONOUS_MODE, backward compatibility parameter.\n
* 								   When used for backward compatibility PCI3009_ASYNCHRONOUS_MODE or PCI3009_SYNCHRONOUS_MODE \n
* 								   can be set but, internally asynchronous is used.
* @param[in] dw_GlobalBufferSize : Not to be used, backward compatibility parameter.
*
* @param[out] ppv_UserBufferRing0 : Not to be used, backward compatibility parameter.
* @param[out] ppv_UserBufferRing3 : Not to be used, backward compatibility parameter.
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Function call level error \n
*         -3: Wrong calling mode \n
*         -4: Interrupt function already installed for this board \n
*         -5: Interrupt installation error 
*/
_INT_ i_PCI3009_SetBoardIntRoutine  (DWORD_   dw_BoardHandle,
						             DWORD_   dw_UserCallingMode,
						             DWORD_   dw_GlobalBufferSize,
						             VOID ** ppv_UserBufferRing0,
						             VOID ** ppv_UserBufferRing3,
						             void (pascal * v_FunctionName) (DWORD_   dw_BoardHandle,
							                                         DWORD_   dw_InterruptSrc,
							                                         DWORD_   dw_InterruptMask,
							                                         PDWORD_ pdw_Value,
							                                         DWORD_   dw_UserCallingMode,
							                                         VOID *   pv_UserSharedMemory));

/*i_PCI3009_SetBoardIntRoutineNew*/
/** This function must be called up for each xPCI-3009 on which an interrupt action is to be enabled. \n
*
* <b>IMPORTANT: i_PCI3009_SetBoardIntRoutineNew function has to be used instead of i_PCI3009_SetBoardIntRoutine.
* i_PCI3009_SetBoardIntRoutine is implemented for backward compatibility reason.</b> \n
*
* It installs a user interrupt function for all boards on which an interrupt is to be enabled. \n
* First calling (first board): \n
*    - the user interrupt routine is installed \n
*    - interrupts are enabled. \n
* If you operate several boards xPCI-3009 which have to react to interrupts, call up the function as often \n
* as you operate boards xPCI-3009. \n
* The variables v_FunctionName for the first calling.\n
* From the second call of the function (next board): \n
* \- Interrupts are enabled. The first board can receive IRQ. \n
* To read the interrupt values when using the sequence DMA mode, use the l_CPCI3009_ReadSequenceData function.\n\n
*
*
* The user interrupt routine must have the following Syntax: \n
* void WINAPI v_FunctionName (DWORD_   dw_BoardHandle,\n
*                             DWORD_   dw_InterruptSrc, \n
*                             DWORD_   dw_InterruptMask, \n
*                             PDWORD_ pdw_Value, \n
*                             DWORD_   dw_UserCallingMode, \n
*                             VOID *   pv_UserSharedMemory) </b>\n\n
* <b>v_FunctionName</b>   Name of the user interrupt routine \n
* <b>dw_BoardHandle</b>   Handle of the xPCI-3009 which has generated the interrupt \n
* <b>dw_InterruptSrc</b>  Interrupt source (0: Analog input / 1: Incremental counter) \n
* <b>dw_InterruptMask</b> Mask of the events which have generated the interrupt. \n
* <b>pdw_Value</b>        Interrupt value \n\n
*
* <table>
*    <tr>
*       <td>dw_InterruptSrc</td>
*       <td>dw_InterruptMask</td>
*       <td>Meaning / pdw_Value</td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>1Hex</td>
*       <td>
*          Single acquisition interrupt (i_PCI3009_AnalogInputRead1Channel or i_PCI3009_AnalogInputReadMoreChannels) \n
*          pdw_Value[0] : Number of acquisitions \n
*          pdw_Value[1] : First channel value \n
*          ... \n
*          pdw_Value[pdw_Value [0] - 1] : Last channel value
*       </td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>2Hex</td>
*       <td>
*          Sequence acquisition interrupt without DMA (i_PCI3009_AnalogInputStartSequence) \n
*          pdw_Value[0] : Number of acquisitions (Sequence size) \n
*          pdw_Value[1] : First sequence channel value \n
*          ... \n
*          pdw_Value [pdw_Value [0] - 1] : Last sequence channel value
*       </td>
*    </tr>
*    <tr>
*       <td>0 (Analog input)</td>
*       <td>4Hex</td>
*       <td>
*          Sequence acquisition interrupt with DMA (i_PCI3009_AnalogInputStartSequence) \n
*          Use l_CPCI3009_ReadSequenceData to read the channels values. \n
*          l_CPCI3009_ReadSequenceData Size of data to read should be ( sequence size * sequence before interrupt ) * sizeof ( USHORT )
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>1Hex</td>
*       <td>
*          Hardware latch of the 1. register (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10001Hex</td>
*       <td>
*          Hardware latch of the 1. register (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>2Hex</td>
*       <td>
*          Hardware latch of the 2. register (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10002Hex</td>
*       <td>
*          Hardware latch of the 2. register (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>4Hex</td>
*       <td>
*          Index interrupt (High level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10004Hex</td>
*       <td>
*          Index interrupt (Low level) \n
*          pdw_Value[0] = Latched counter value
*       </td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>8Hex</td>
*       <td>Compare interrupt</td>
*    </tr>
*    <tr>
*       <td>1 (Incremental counter)</td>
*       <td>10Hex</td>
*       <td>
*          Interrupt at the end of frequency measurement \n
*          pdw_Value[0] = Measured value
*    </tr>
*    <tr>
*       <td>2 (Chronos)</td>
*       <td>1Hex</td>
*       <td>
*          Interrupt at the end of chronos measurement \n
*          pdw_Value[0] = Measured value
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>1Hex</td>
*       <td>
*          Timer 0 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>2Hex</td>
*       <td>
*          Counter 0 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>8Hex</td>
*       <td>
*          Timer 1 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>10Hex</td>
*       <td>
*          Counter 1 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>20Hex</td>
*       <td>
*          Watchdog 1 (analog output) run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>40Hex</td>
*       <td>
*          Timer 2 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>80Hex</td>
*       <td>
*          Counter 2 run down
*       </td>
*    </tr>
*    <tr>
*       <td>4 (Timer/counter/watchdog)</td>
*       <td>100Hex</td>
*       <td>
*          Watchdog 2 (digital output) run down
*       </td>
*    </tr>
* </table> \n
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -4: Interrupt function already installed for this board \n
*         -5: Interrupt installation error
*/
_INT_ i_PCI3009_SetBoardIntRoutineNew  (DWORD_   dw_BoardHandle,
                                     void (pascal * v_FunctionName) (DWORD_   dw_BoardHandle,
                                             DWORD_   dw_InterruptSrc,
                                             DWORD_   dw_InterruptMask,
                                             PDWORD_ pdw_Value,
                                             DWORD_   dw_UserCallingMode,
                                             VOID *   pv_UserSharedMemory));

/*i_PCI3009_ResetBoardIntRoutine*/
/** Stops the interrupt administration of the xPCI-3009.\n
* Deinstalls the interrupt routine if the interrupt administration of all xPCI-3009 is stopped.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Function call level error \n
*         -3: Interrupt function nor installed for this board
*/
_INT_ i_PCI3009_ResetBoardIntRoutine  (DWORD_ dw_BoardHandle);

/** Read data acquired by a sequence acquisition. \n
* This function can be called in the interrupt routine that you registered. (see samples) \n
*
* @param[out] dw_BoardHandle : Handle to the board
* @param[in]  dw_size        : Size of data to read. To be powerfull, should be ( sequence size * sequence before interrupt ) * sizeof ( USHORT )
* @return	>= 0:	size of data read \n
*			-1	:	error while reading
*/
_LONG_ l_PCI3009_ReadSequenceData(DWORD_ dw_BoardHandle,
						 DWORD dw_size,
						 PVOID data);


/*i_PCI3009_CloseBoard*/
/** Releases the handle of the board.Blocks the access to the board. \n\n
*
* <b>IMPORTANT!</b>\n
* <b>Call up this function each time when you want to leave the user program!</b>
*                                                                          
* @param[in] dw_BoardHandle           : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_CloseBoard (DWORD_ dw_BoardHandle);

/* @} */


/** \defgroup PCI3009_DIG_INP_24V PCI-3009 digital input functions
* \ingroup PCI3009
* @{
*/

/*i_PCI3009_DigitalInputEnableDisableFilter*/
/** Enable/disable the digital input filter. The filter time base is 1 micro s.
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in]  b_Filter         : PCI3009_DISABLE: Disable the digital input filter \n
*                                PCI3009_ENABLE : Enable the digital input filter
* @param[in]  dw_FilterTime    : Digital input filter time (1 to 2047). Time base is 1 micro s
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong filter selection \n
*         -3: Wrong filter time 
*/
_INT_ i_PCI3009_DigitalInputEnableDisableFilter (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_Filter,
												 DWORD_ dw_FilterTime);


/*i_PCI3009_DigitalInputRead1*/
/** Read the selected digital input channel
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in]  b_Channel        : Selected digital input channel (0 to 3)
*
* @param[out]  pb_State        : 0: Input is low (0V) \n
*                                1: nput is high (24V)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel selection
*/
_INT_ i_PCI3009_DigitalInputRead1 (DWORD_ dw_BoardHandle,
                                   BYTE_   b_Channel,
								   PBYTE_ pb_State);



/*i_PCI3009_DigitalInputReadAll*/
/** Read all digital input channels
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_State         : D0: Digital input 0 state \n
*                                D1: Digital input 1 state \n
*                                D2: Digital input 2 state \n
*                                D3: Digital input 3 state
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_DigitalInputReadAll (DWORD_ dw_BoardHandle,
									 PBYTE_ pb_State);

/* @} */


/** \defgroup PCI3009_DIG_OUT_24V PCI-3009 digital output functions
* \ingroup PCI3009
* @{
*/

/*i_PCI3009_DigitalOutputWriteAll*/
/** Write the selected value to the digital outputs
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] b_WriteValue     : D0: Digital output 0 state. 0 -> Set to low (0V) \n
*                                                            1 -> Set to high (24V) \n
*                                D1: Digital output 1 state. 0 -> Set to low (0V) \n
*                                                            1 -> Set to high (24V) \n
*                                D2: Digital output 2 state. 0 -> Set to low (0V) \n
*                                                            1 -> Set to high (24V) \n
*                                D3: Digital output 3 state. 0 -> Set to low (0V) \n
*                                                            1 -> Set to high (24V)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*         -2: Wrong write value
*/
_INT_ i_PCI3009_DigitalOutputWriteAll (DWORD_ dw_BoardHandle,
									   BYTE_   b_WriteValue);



/*i_PCI3009_DigitalOutputReadAll*/
/** Read all digital output channels
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_State         : D0: Digital output 0 state \n
*                                D1: Digital output 1 state \n
*                                D2: Digital output 2 state \n
*                                D3: Digital output 3 state
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_DigitalOutputReadAll (DWORD_ dw_BoardHandle,
									  PBYTE_ pb_State);

/* @} */

/** \defgroup PCI3009_ANA_OUT PCI-3009 analog output functions
* \ingroup PCI3009
* @{
*/

/*i_PCI3009_AnalogOutputWrite1Channel*/
/** Set 1 analog output of the board xPCI-3009
*                                                                          
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_Channel           : Channel number of the analog output to set (0 to 3)
* @param[in] w_AnalogOutputValue : Analog output value to set on the selected analog output channel (0:-10V, 2048=0V, 4095=+10V)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The channel number parameter is wrong \n
*         -3: The channel value parameter is wrong
*/

_INT_   i_PCI3009_AnalogOutputWrite1Channel (DWORD_ dw_BoardHandle,
                                             BYTE_   b_Channel,
                                             WORD_   w_AnalogOutputValue);


/*i_PCI3009_AnalogOutputWriteMoreChannels*/
/** Set more analog output of the board xPCI-3009
*                                                                          
* @param[in] dw_BoardHandle           : Handle of board PCI-3009
* @param[in] b_NbrOfChannels          : Nbr of channels so setings (1 to 4)
* @param[in] pb_ChannelList           : Channel number list of the analog output to set (0 to 3)
* @param[in] pw_AnalogOutputValueList : Analog output value list to set on the selected analog output channel (0:-10V, 2048=0V, 4095=+10V)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channels number selection \n
*         -3: The channel index 0 number parameter is wrong \n
*         -4: The channel index 0 value parameter is wrong \n
*         -5: The channel index 1 number parameter is wrong \n
*         -6: The channel index 1 value parameter is wrong \n
*         -7: The channel index 2 number parameter is wrong \n
*         -8: The channel index 2 value parameter is wrong \n
*         -9: The channel index 3 number parameter is wrong \n
*         -10: The channel index 3 value parameter is wrong
*/

_INT_   i_PCI3009_AnalogOutputWriteMoreChannels (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_NbrOfChannels,
                                                 PBYTE_ pb_ChannelList,
                                                 PWORD_ pw_AnalogOutputValueList);

/* @} */


/** \defgroup PCI3009_TCW PCI-3009 timer/counter/watchdog functions
* \ingroup PCI3009
* @{
*/


/*i_PCI3009_TmrCptWatInit*/
/** Read the selected digital input channel
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in]  b_TmrCptWat      : Selected timer/counter/watchdog (0 to 2)
* @param[in] dw_OperatingMode  : Timer/counter/watchdog operating mode selection \n
*                                PCI3009_TIMER \n
*                                Enable the timer down count mode. After initialization the timer is set to dw_ReloadValue. \n
*                                After the activation the timer is decremented all seleted time base (micro s, milli s or s). \n
*                                After dw_ReloadValue decrements to timer reload the value dw_ReloadValue and can generated a interrupt. \n
*                                PCI3009_UP_COUNTER \n
*                                Enable the counter up count mode. After initialization the counter is set to 0. \n
*                                After the activation the counter is incremented for each high level input puls (Input 1 for counter 0, Input 2 for counter 1 and Input 3 for counter 2). \n
*                                After dw_ReloadValue - 1 increments puls to counter reload the value 0 and can generated a interrupt. \n
*                                PCI3009_DOWN_COUNTER \n
*                                Enable the counter down count mode. After initialization the counter is set to dw_ReloadValue. \n
*                                After the activation the counter is decremented for each high level input puls (Input 1 for counter 0, Input 2 for counter 1 and Input 3 for counter 2). \n
*                                After dw_ReloadValue decrements puls to counter reload the value dw_ReloadValue and can generated a interrupt. \n
*                                PCI3009_WATCHDOG \n
*                                Only available for timer/counter/watchdog 1 and 2. \n
*                                Watchdog 1 is used for the analog outputs. \n
*                                Watchdog 2 is used for the digital outputs. \n
*                                After initialization and activation the watchdog is ready. The next hardware access start the watchdog and each next access reload the watchdog. \n
*                                If no access occur into the selected time, the watchog run down and the outputs are reseted an the watchdog can generated a interrupt.
* @param[in] dw_ReloadValue    : Define the reload value for the down mode and the max value for the up mode. 
* @param[in] b_TimeBase        : Timer/watchdog time base selection. \n
*                                PCI3009_MICRO_SECOND :micros \n
*                                PCI3009_MILLI_SECOND :ms \n
*                                PCI3009_SECOND :s
* @param[in] dw_OutputAction   : Each timer/counter/watchdog have a digital output affected. \n
*                                - Outpout 0 for timer/counter/watchdog 0 \n
*                                - Outpout 1 for timer/counter/watchdog 1 \n
*                                - Outpout 2 for timer/counter/watchdog 2 \n
*                                PCI3009_SET_LOW: \n
*                                Set the output to low by a timer/counter/watchdog run down cycle. \n
*                                For the timer/counter the output is set to high by the next puls. \n
*                                PCI3009_SET_HIGH: \n
*                                Set the output to high by a timer/counter/watchdog run down cycle. \n
*                                For the timer/counter the output is set to low by the next puls. \n
*                                PCI3009_FLIP_FLOP: \n
*                                Only available for the timers. After the first run down cycle the output is set to high. \n
*                                The next run down cycle set the output to low, the next run down cycle set the output to high, .... \n
*                                This make a flip flop action.
* @param[in] b_InterruptEnable : Interrupt management. \n
*                                PCI3009_DISABLE: \n
*                                No interrupt are generated after a run down cycle. \n
*                                PCI3009_DISABLE: \n
*                                Interrupt are generated after a run down cycle.
*                                
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Timer/counter/watchdog selection wrong \n
*         -3: Operating mode selection wrong \n
*         -4: Reload value selection wrong \n
*         -5: Time base selection wrong \n
*         -6: Output action selection wrong \n
*         -7: Interrupt flag wrong \n
*         -8: Interrupt function not initialised
*/
_INT_ i_PCI3009_TmrCptWatInit (DWORD_ dw_BoardHandle,
                               BYTE_   b_TmrCptWat,
							   DWORD_ dw_OperatingMode,
							   DWORD_ dw_ReloadValue,
							   BYTE_   b_TimeBase,
							   DWORD_ dw_OutputAction,
							   BYTE_   b_InterruptEnable);


/*i_PCI3009_TmrCptWatEnable*/
/** Enable the selected timer/counter/watchdog. For the watchdog, the next hardware access start the watchdog.
*
* @param[in]  dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_TmrCptWat      : Selected timer/counter/watchdog (0 to 2)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Timer/counter/watchdog selection wrong \n
*         -3: Timer/counter/watchdog not initialised
*/
_INT_ i_PCI3009_TmrCptWatEnable (DWORD_ dw_BoardHandle,
                                 BYTE_   b_TmrCptWat);


/*i_PCI3009_TmrCptWatDisable*/
/** Disable the selected timer/counter/watchdog. 
*
* @param[in]  dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_TmrCptWat      : Selected timer/counter/watchdog (0 to 2)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Timer/counter/watchdog selection wrong \n
*         -3: Timer/counter/watchdog not initialised
*/
_INT_ i_PCI3009_TmrCptWatDisable (DWORD_ dw_BoardHandle,
                                  BYTE_   b_TmrCptWat);


/*i_PCI3009_TmrCptWatGetStatus*/
/** Get the selected timer/counter/watchdog status (Actualy value, down status and trigger status). 
*
* @param[in]  dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_TmrCptWat      : Selected timer/counter/watchdog (0 to 2)
*
* @param[out] pdw_Value         : Actualy timer/counter/watchdog value
* @param[out]  pb_DownStatus    : 0: No run down occur \n
*                                 1: Run down occur
* @param[out]  pb_TriggerStatus : 0: No trigger occur \n
*                                 1: Software trigger occur
*
* @param[out] pb_OutputState    : 0: output is low \n
*                                 1: output is high
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Timer/counter/watchdog selection wrong \n
*         -3: Timer/counter/watchdog not initialised
*/
_INT_ i_PCI3009_TmrCptWatGetStatus (DWORD_   dw_BoardHandle,
                                    BYTE_     b_TmrCptWat,
								    PDWORD_ pdw_Value,
								    PBYTE_   pb_DownStatus,
								    PBYTE_   pb_TriggerStatus,
									PBYTE_   pb_OutputState);

/*i_PCI3009_TmrCptWatDisable*/
/** Trigger the selected timer/counter/watchdog. Down mode reload the initial value, up mode reload 0.
*
* @param[in]  dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_TmrCptWat      : Selected timer/counter/watchdog (0 to 2)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Timer/counter/watchdog selection wrong \n
*         -3: Timer/counter/watchdog not initialised
*/
_INT_ i_PCI3009_TmrCptWatTrigger (DWORD_ dw_BoardHandle,
                                  BYTE_   b_TmrCptWat);

/* @} */


/** \defgroup PCI3009_ANA_INP PCI-3009 analog input functions
* \ingroup PCI3009
* @{
*/


/** \defgroup PCI3009_ANA_INP_INIT PCI-3009 analog input initialisation functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/*i_PCI3009_AnalogInputInitMode*/
/** Initialises the analog inputs single/diff mode
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in]  b_SingelDiffMode : PCI3009_SINGLE : Single mode \n
*                                PCI3009_DIFF   : Diff mode
*
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong single/diff mode \n
*         -3: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputInitMode (DWORD_ dw_BoardHandle,
                                     BYTE_   b_SingelDiffMode);

/*i_PCI3009_AnalogInputInitChannel*/
/** Initialises one analog input channel                   
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in]   b_Channel      : Channel number of the input to be initialise
* @param[in]   b_Gain         : Gain factor of the analog input\n
*                                              - PCI3009_1_GAIN : Gain =  1  \n
*                                              - PCI3009_2_GAIN : Gain =  2  \n
*                                              - PCI3009_5_GAIN : Gain =  5  \n
*                                              - PCI3009_10_GAIN: Gain = 10
* @param[in]   b_Polarity     : Polarity of the analog input:  \n
*                                              - PCI3009_UNIPOLAR:  0V - +10V\n
*                                              - PCI3009_BIPOLAR: -10V - +10V
*
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Single / Diff not initialized\n
*         -3: Wrong channel number \n
*         -4: Wrong gain \n
*         -5: Wrong polarity \n
*         -6: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputInitChannel (DWORD_ dw_BoardHandle,
                                        BYTE_   b_Channel,
                                        BYTE_   b_Gain, 
                                        BYTE_   b_Polarity);

/* @} */


/** \defgroup PCI3009_ANA_INP_CONVERT PCI-3009 analog input convert value functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/*i_PCI3009_AnalogInputConvertDigitalToRealAnalogValuel*/
/** Convert the digital value to analog value     
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in]   b_Channel         : Channel number of the input to be convert
* @param[in] dw_DigitalValue     : Digital analog value
*
* @param[out] pd_AnalogValue     : Return the analog value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number \n
*         -3: Channel not initialised
*/
_INT_ i_PCI3009_AnalogInputConvertDigitalToRealAnalogValue (DWORD_   dw_BoardHandle,
                                                            BYTE_     b_Channel,
  		                		                            DWORD_   dw_DigitalValue,
								                            DOUBLE * pd_AnalogValue);


/*i_PCI3009_AnalogInputConvertDigitalToRealAnalogValuel*/
/** Convert the digital value to analog value     
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in]  b_NbrOfChannels    : Nbr of channels to convert (1 to 16)
* @param[in] pb_ChannelList      : Channel number list of the analog input to convert
* @param[in] pdw_DigitalValue    : Digital analog value array
*
* @param[out] pd_AnalogValue     : Return the analog value array
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channels number selection \n
*         -3: Wrong channel index 0 number \n
*         -4: Channel index 0 not initialised \n
*         -5: Wrong channel index 1 number \n
*         -6: Channel index 1 not initialised \n
*         -7: Wrong channel index 2 number \n
*         -8: Channel index 2 not initialised \n
*         -9: Wrong channel index 3 number \n
*         -10: Channel index 3 not initialised \n
*         -11: Wrong channel index 4 number \n
*         -12: Channel index 4 not initialised \n
*         -13: Wrong channel index 5 number \n
*         -14: Channel index 5 not initialised \n
*         -15: Wrong channel index 6 number \n
*         -16: Channel index 6 not initialised \n
*         -17: Wrong channel index 7 number \n
*         -18: Channel index 7 not initialised \n
*         -19: Wrong channel index 8 number \n
*         -20: Channel index 8 not initialised \n
*         -21: Wrong channel index 9 number \n
*         -22: Channel index 9 not initialised \n
*         -23: Wrong channel index 10 number \n
*         -24: Channel index 10 not initialised \n
*         -25: Wrong channel index 11 number \n
*         -26: Channel index 11 not initialised \n
*         -27: Wrong channel index 12 number \n
*         -28: Channel index 12 not initialised \n
*         -29: Wrong channel index 13 number \n
*         -30: Channel index 13 not initialised \n
*         -31: Wrong channel index 14 number \n
*         -32: Channel index 14 not initialised \n
*         -33: Wrong channel index 15 number \n
*         -34: Channel index 15 not initialised \n
*/
_INT_ i_PCI3009_AnalogInputConvertMoreDigitalToRealAnalogValues (DWORD_    dw_BoardHandle,
                                                                 BYTE_      b_NbrOfChannels,
                                                                 PBYTE_    pb_ChannelList,
  		                		                                 PDWORD_  pdw_DigitalValue,
								                                 DOUBLE *  pd_AnalogValue);


/* @} */


/** \defgroup PCI3009_ANA_INP_SINGLE PCI-3009 analog input single acquisition functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/*i_PCI3009_AnalogInputRead1Channel*/
/** Starts the conversion of one analog input channel      
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in]   b_Channel         : Channel number of the input to be read
* @param[in]   b_ConvertTimeUnit : Convert time unit for the analog input: \n
*                                              - PCI3009_MICRO_SECOND :micros\n
*                                              - PCI3009_MILLI_SECOND :ms
* @param[in]   w_ConvertTime     : Convert time value for the analog input conversion \n
*                                              - PCI3009_MICRO_SECOND :(10 to 65535)\n
*                                              - PCI3009_MILLI_SECOND :(1 to 65535)
*
* @param[in]   b_Interrupt       : Interrupt flag\n
*                                              - PCI3009_DISABLE : Interrupt not used. pdw_DigitalValue return the digital value \n
*                                              - PCI3009_ENABLE  : Interrupt generated after conversion (EOC). pdw_DigitalValue is not used
*
* @param[out] pdw_DigitalValue   : Return the digital analog value if interrupt not used
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number \n
*         -3: Channel not initialised \n
*         -4: Wrong convert time unit \n
*         -5: Wrong convert time \n
*         -6: Wrong interrupt flag \n
*         -7: Interrupt routine not installed see function "i_PCI3009_SetBoardIntRoutine" \n
*         -8: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputRead1Channel (DWORD_   dw_BoardHandle,
                                         BYTE_     b_Channel,
  		                		         BYTE_     b_ConvertTimeUnit,
		                		         WORD_     w_ConvertTime,
								         BYTE_     b_Interrupt,
								         PDWORD_ pdw_DigitalValue);


/*i_PCI3009_AnalogInputReadMoreChannels*/
/** Starts the conversion of more analog input channels
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in]  b_NbrOfChannels    : Nbr of channels so setings (1 to 16)
* @param[in] pb_ChannelList      : Channel number list of the analog input to read
* @param[in]   b_ConvertTimeUnit : Convert time unit for the analog input: \n
*                                              - PCI3009_MICRO_SECOND :micros\n
*                                              - PCI3009_MILLI_SECOND :ms
* @param[in]   w_ConvertTime     : Convert time value for the analog input conversion \n
*                                              - PCI3009_MICRO_SECOND :(10 to 65535)\n
*                                              - PCI3009_MILLI_SECOND :(1 to 65535)
* @param[in]   b_Interrupt       : Interrupt flag\n
*                                              - PCI3009_DISABLE : Interrupt not used. pdw_DigitalValue return the digital value \n
*                                              - PCI3009_ENABLE  : Interrupt generated after conversion (EOC). pdw_DigitalValue is not used
*
* @param[out] pdw_DigitalValue   : Return the digital analog value if interrupt not used
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channels number selection \n
*         -3: Wrong channel index 0 number \n
*         -4: Channel index 0 not initialised \n
*         -5: Wrong channel index 1 number \n
*         -6: Channel index 1 not initialised \n
*         -7: Wrong channel index 2 number \n
*         -8: Channel index 2 not initialised \n
*         -9: Wrong channel index 3 number \n
*         -10: Channel index 3 not initialised \n
*         -11: Wrong channel index 4 number \n
*         -12: Channel index 4 not initialised \n
*         -13: Wrong channel index 5 number \n
*         -14: Channel index 5 not initialised \n
*         -15: Wrong channel index 6 number \n
*         -16: Channel index 6 not initialised \n
*         -17: Wrong channel index 7 number \n
*         -18: Channel index 7 not initialised \n
*         -19: Wrong channel index 8 number \n
*         -20: Channel index 8 not initialised \n
*         -21: Wrong channel index 9 number \n
*         -22: Channel index 9 not initialised \n
*         -23: Wrong channel index 10 number \n
*         -24: Channel index 10 not initialised \n
*         -25: Wrong channel index 11 number \n
*         -26: Channel index 11 not initialised \n
*         -27: Wrong channel index 12 number \n
*         -28: Channel index 12 not initialised \n
*         -29: Wrong channel index 13 number \n
*         -30: Channel index 13 not initialised \n
*         -31: Wrong channel index 14 number \n
*         -32: Channel index 14 not initialised \n
*         -33: Wrong channel index 15 number \n
*         -34: Channel index 15 not initialised \n
*         -35: Wrong convert time unit \n
*         -36: Wrong convert time \n
*         -37: Wrong interrupt flag \n
*         -38: Interrupt routine not installed see function "i_PCI3009_SetBoardIntRoutine" \n
*         -39: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputReadMoreChannels (DWORD_   dw_BoardHandle,
                                             BYTE_     b_NbrOfChannels,
                                             PBYTE_   pb_ChannelList,
                                             BYTE_     b_ConvertTimeUnit,
                                             WORD_     w_ConvertTime,
                                             BYTE_     b_Interrupt,
                                             PDWORD_ pdw_DigitalValue);


/* @} */


/** \defgroup PCI3009_ANA_INP_AUTO_REFRESH PCI-3009 analog input auto refresh functions
* \ingroup PCI3009_ANA_INP
* @{
*/


/*i_PCI3009_AnalogInputGetAutoRefreshChannelPointer*/
/** Get the ring 0 and ring 3 address from selected analog input auto refresh channel
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in]   b_Channel      : Channel number to get the auto refresh address pointer
*
* @param[out] ppdw_Ring0Pointer : Return the ring 0 auto refresh channel address pointer
* @param[out] ppdw_Ring3Pointer : Return the ring 3 auto refresh channel address pointer

* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number
*/
_INT_ i_PCI3009_AnalogInputGetAutoRefreshChannelPointer (DWORD_      dw_BoardHandle,
                                                         BYTE_        b_Channel,
                                                         PDWORD_ * ppdw_Ring0Pointer,
														 PDWORD_ * ppdw_Ring3Pointer);

/*i_PCI3009_AnalogInputGetAutoRefreshModulPointer*/
/** Get the ring 0 and ring 3 address from analog input auto refresh modul
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
*
* @param[out] ppdw_Ring0Pointer : Return the ring 0 auto refresh modul address pointer
* @param[out] ppdw_Ring3Pointer : Return the ring 3 auto refresh modul address pointer
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_AnalogInputGetAutoRefreshModulPointer (DWORD_      dw_BoardHandle,
                                                       PDWORD_ * ppdw_Ring0Pointer,
													   PDWORD_ * ppdw_Ring3Pointer);


/*i_PCI3009_AnalogInputGetAutoRefreshCounterPointer*/
/** Get the ring 0 and ring 3 address from analog input auto refresh counter
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
*
* @param[out] ppdw_Ring0Pointer : Return the ring 0 auto refresh counter address pointer
* @param[out] ppdw_Ring3Pointer : Return the ring 3 auto refresh counter address pointer
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_AnalogInputGetAutoRefreshCounterPointer (DWORD_      dw_BoardHandle,
                                                         PDWORD_ * ppdw_Ring0Pointer,
													     PDWORD_ * ppdw_Ring3Pointer);


/*i_PCI3009_AnalogInputStartAutoRefresh*/
/** Starts Initialise and start an analog input auto refresh conversion     
*
* @param[in] dw_BoardHandle     : Handle of board PCI-3009
* @param[in]  w_ChannelMask     : Channel mask to acquire. D0 0: Channel 0 not used \n
*                                                             1: Channel 0 used \n
*                                                          D1 0: Channel 1 not used \n
*                                                             1: Channel 1 used \n
*                                                          . \n
*                                                          . \n
*                                                          . \n
*                                                          D15 0: Channel 15 not used \n
*                                                              1: Channel 15 used
* @param[in]  b_ConvertTimeUnit : Convert time unit for the analog input: \n
*                                              - PCI3009_MICRO_SECOND :micros\n
*                                              - PCI3009_MILLI_SECOND :ms
* @param[in]  w_ConvertTime     : Convert time value for the analog input conversion \n
*                                              - PCI3009_MICRO_SECOND :(10 to 65535)\n
*                                              - PCI3009_MILLI_SECOND :(1 to 65535)
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channels mask selection \n
*         -3: Wrong channel 0 mask \n
*         -4: Channel 0 not initialised \n
*         -5: Wrong channel 1 mask \n
*         -6: Channel 1 not initialised \n
*         -7: Wrong channel 2 mask \n
*         -8: Channel 2 not initialised \n
*         -9: Wrong channel 3 mask \n
*         -10: Channel 3 not initialised \n
*         -11: Wrong channel 4 mask \n
*         -12: Channel 4 not initialised \n
*         -13: Wrong channel 5 mask \n
*         -14: Channel 5 not initialised \n
*         -15: Wrong channel 6 mask \n
*         -16: Channel 6 not initialised \n
*         -17: Wrong channel 7 mask \n
*         -18: Channel 7 not initialised \n
*         -19: Wrong channel 8 mask \n
*         -20: Channel 8 not initialised \n
*         -21: Wrong channel 9 mask \n
*         -22: Channel 9 not initialised \n
*         -23: Wrong channel 10 mask \n
*         -24: Channel 10 not initialised \n
*         -25: Wrong channel 11 mask \n
*         -26: Channel 11 not initialised \n
*         -27: Wrong channel 12 mask \n
*         -28: Channel 12 not initialised \n
*         -29: Wrong channel 13 mask \n
*         -30: Channel 13 not initialised \n
*         -31: Wrong channel 14 mask \n
*         -32: Channel 14 not initialised \n
*         -33: Wrong channel 15 mask \n
*         -34: Channel 15 not initialised \n
*         -35: Wrong convert time unit \n
*         -36: Wrong convert time \n
*         -37: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputStartAutoRefresh (DWORD_ dw_BoardHandle,
                                             WORD_   w_ChannelMask,
  		                		             BYTE_   b_ConvertTimeUnit,
		                		             WORD_   w_ConvertTime);



/*i_PCI3009_AnalogInputReadAutoRefreshValueAndCounter*/
/** Read the auto refresh values                                          
*
* @param[in] dw_BoardHandle     : Handle of board PCI-3009
*
* @param[out] pdw_ReadValue     : Ret the actualy auto refresh channel value. \n
*                                     pdw_ReadValue [0] : Channel 0 value \n
*                                     pdw_ReadValue [1] : Channel 1 value \n
*                                     . \n
*                                     . \n
*                                     . \n
*                                     pdw_ReadValue [15] : Channel 15 value
* @param[out] pdw_CycleIndex    : Return the number of auto refresch cycles
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: No conversion started
*/
_INT_ i_PCI3009_AnalogInputReadAutoRefreshValueAndCounter (DWORD_   dw_BoardHandle,
			                                               PDWORD_ pdw_ReadValue, 
			                                               PDWORD_ pdw_CycleIndex);



/*i_PCI3009_AnalogInputStopAutoRefresh*/
/** Stop an analog input auto refresh conversion
*
* @param[in] dw_BoardHandle     : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: No conversion started
*/
_INT_ i_PCI3009_AnalogInputStopAutoRefresh (DWORD_ dw_BoardHandle);



/* @} */



/** \defgroup PCI3009_ANA_INP_SEQUENCE PCI-3009 analog input sequence functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/*i_PCI3009_AnalogInputInitSequence*/
/** Initialise an analog input sequence conversion         
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in]  b_NbrOfChannels    : Nbr of channels so setings (1 to 16)
* @param[in] pb_ChannelList      : Channel number list of the analog input to read
* @param[in]  b_ConvertTimeUnit  : Convert time unit for the analog input: \n
*                                              - PCI3009_MICRO_SECOND :micros\n
*                                              - PCI3009_MILLI_SECOND :ms
* @param[in]  w_ConvertTime      : Convert time value for the analog input conversion \n
*                                              - PCI3009_MICRO_SECOND :(10 to 65535)\n
*                                              - PCI3009_MILLI_SECOND :(1 to 65535)
* @param[in]   b_DelayMode       : Delay mode for the analog input: \n
*                                              - PCI3009_DISABLE: Delay no used \n
*                                              - PCI3009_DELAY_MODE_1: Mode 1 \n
*                                              - PCI3009_DELAY_MODE_2: Mode 2 \n
* @param[in]   b_DelayTimeUnit   : Delay time unit for the analog input: \n
*                                              - PCI3009_MICRO_SECOND :micros\n
*                                              - PCI3009_MILLI_SECOND :ms
* @param[in]   w_DelayTime       : Delay time value for the analog input conversion \n
* @param[in]  dw_NumberOfSequence :   Define the number of sequence acquisitions \n
*                                               -    0: continuous mode \n
*                                               - <> 0: single mode
* @param[in]    b_UseDMA         : ADDIDATA_ENABLE  : Use DMA \n
*                                  ADDIDATA_DISABLE : Don't use DMA
* @param[in]  dw_NumberOfSequenceForEachInterrupt : Number of sequence to do before generating an interrupt (Only for DMA)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channels number selection \n
*         -3: Wrong channel index 0 number \n
*         -4: Channel index 0 not initialised \n
*         -5: Wrong channel index 1 number \n
*         -6: Channel index 1 not initialised \n
*         -7: Wrong channel index 2 number \n
*         -8: Channel index 2 not initialised \n
*         -9: Wrong channel index 3 number \n
*         -10: Channel index 3 not initialised \n
*         -11: Wrong channel index 4 number \n
*         -12: Channel index 4 not initialised \n
*         -13: Wrong channel index 5 number \n
*         -14: Channel index 5 not initialised \n
*         -15: Wrong channel index 6 number \n
*         -16: Channel index 6 not initialised \n
*         -17: Wrong channel index 7 number \n
*         -18: Channel index 7 not initialised \n
*         -19: Wrong channel index 8 number \n
*         -20: Channel index 8 not initialised \n
*         -21: Wrong channel index 9 number \n
*         -22: Channel index 9 not initialised \n
*         -23: Wrong channel index 10 number \n
*         -24: Channel index 10 not initialised \n
*         -25: Wrong channel index 11 number \n
*         -26: Channel index 11 not initialised \n
*         -27: Wrong channel index 12 number \n
*         -28: Channel index 12 not initialised \n
*         -29: Wrong channel index 13 number \n
*         -30: Channel index 13 not initialised \n
*         -31: Wrong channel index 14 number \n
*         -32: Channel index 14 not initialised \n
*         -33: Wrong channel index 15 number \n
*         -34: Channel index 15 not initialised \n
*         -35: Wrong convert time unit \n
*         -36: Wrong convert time \n
*         -37: Wrong delay mode \n
*         -38: Wrong delay time unit \n
*         -39: Wrong delay time \n
*         -40: Wrong DMA mode \n
*         -41: Wrong number of sequence value for each interrupt \n
*         -42: Conversion is already started \n
*         -43: Scatter gather memory allocation error \n
*         -44: Scatter gather list descriptor creation error
*/
_INT_ i_PCI3009_AnalogInputInitSequence (DWORD_  dw_BoardHandle,
                                         BYTE_    b_NbrOfChannels,
                                         PBYTE_  pb_ChannelList,
  		                		         BYTE_    b_ConvertTimeUnit,
		                		         WORD_    w_ConvertTime,
                                         BYTE_    b_DelayMode,
                                         BYTE_    b_DelayTimeUnit,
                                         WORD_    w_DelayTime,
                                         DWORD_  dw_NumberOfSequence,
										 BYTE_    b_UseDMA,
										 DWORD_  dw_NumberOfSequenceForEachInterrupt);

/*i_PCI3009_AnalogInputStartSequence*/
/** Start an analog input sequence conversion              
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Sequence not initialised \n
*         -3: Interrupt routine not installed see function "i_PCI3009_SetBoardIntRoutine" \n
*         -4: A conversion is already started \n
*         -5: Description list setting error \n
*         -6: Enable DMA transfer error \n
*         -7: Start DMA transfer error \n
*         -8: Enable DMA transfer interrupt error
*/
_INT_ i_PCI3009_AnalogInputStartSequence (DWORD_  dw_BoardHandle);


/*i_PCI3009_AnalogInputStopSequence*/
/** Stop an analog input sequence conversion               
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Sequence not started \n
*         -3: Disable the DMA transfer error \n
*         -4: Abort the DMA transfer error \n
*         -5: Stop the DMA transfer error \n
*         -6: Reset descriptor list error
*/
_INT_ i_PCI3009_AnalogInputStopSequence (DWORD_  dw_BoardHandle);


/*i_PCI3009_AnalogInputReleaseSequence*/
/** Release an analog input sequence conversion
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Sequence not initialised \n
*         -3: Sequence acquisition started \n
*         -4: Function call level error
*/
_INT_ i_PCI3009_AnalogInputReleaseSequence (DWORD_  dw_BoardHandle);

/*i_PCI3009_AnalogInputConvertDMADigitalToRealAnalogValues*/
/** Converts the sequence digital input value array (pdw_DigitalValue) into a real metric value (pd_MetricValue)
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] pdw_DigitalValue : Digital DMA value array
*
* @param[out] pd_AnalogValue : Returns the real analog value array
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Sequence not initialised \n
*         -3: DMA not enabled
*/
_INT_ i_PCI3009_AnalogInputConvertDMADigitalToRealAnalogValues (DWORD_   dw_BoardHandle,
                                                                PDWORD_ pdw_DigitalValue,
                                                                DOUBLE  *pd_AnalogValue);


/*i_PCI3009_AnalogInputConvertDMADigitalToRealAnalogValuesNew*/
/** Converts the sequence digital input value array (pdw_DigitalValue) into a real metric value (pd_MetricValue)
 *
 * @param[in] dw_BoardHandle   : Handle of board PCI-3009
 * @param[in] dw_Size : Number of values in pw_DigitalValue
 * @param[in] pw_DigitalValue : Digital DMA value array
 *
 * @param[out] pd_AnalogValue : Returns the real analog value array
 *
 * @return  0: No error \n
 *         -1: The handle parameter of the board is wrong \n
 *         -2: Sequence not initialised \n
 *         -3: DMA not enabled
 */
_INT_ i_PCI3009_AnalogInputConvertDMADigitalToRealAnalogValuesNew (DWORD_   dw_BoardHandle,
																	DWORD_ dw_Size,
																	PWORD_ pw_DigitalValue,
																	DOUBLE  *pd_AnalogValue);

/* @} */


/** \defgroup PCI3009_ANA_INP_COMPARE PCI-3009 analog input compare logic functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/**
 * \struct str_CompareLogicResult
 */
typedef struct
	{
	BYTE b_Open; /*!< 1: No connection to the analog input (Only for unipolar mode)  */
	BYTE b_IsInFirstRange; /*!< 1: Analog value in the first compare range (value < Compare value level A) */
	BYTE b_IsInSecondRange; /*!< 1: Analog value in the second compare range (Compare value level A < value < Compare value level B) */
	BYTE b_IsInThirdRange; /*!< 1: Analog value in the second compare range (value > Compare value level B) */
	BYTE b_Reserved[4]; /*!< Not used */
	}str_CompareLogicResult,*pstr_CompareLogicResult;

/**
 * \struct str_AutoRefreshDataPackage
 */
typedef struct
{
	DWORD                   dw_ChannelIncrementValue; /*!< Auto refresh acquisition pointer */
	BYTE                    b_Reserved[4]; /*!< Not used */
	DOUBLE                  d_ChannelValue; /*!< Analog channel value */
	str_CompareLogicResult  s_DigitalizedValue; /*! str_CompareLogicResult struct */
}str_AutoRefreshDataPackage, *pstr_AutoRefreshDataPackage;


/*i_PCI3009_AnalogInputInitCompareLogic*/
/** Initialises the selected analog input channel compare logic. You can define 2 levels for each channel
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in]  b_Channel            : Channel number of the input to be initialise
* @param[in]  b_CompareLevelAMode  : Level A compare mode: \n
*                                     0 : Compare logic disabled \n
*                                     1 : Compare logic analog value = compare value enabled \n
*                                     2 : Compare logic analog value > compare value enabled \n
*                                     3 : Compare logic analog value < compare value enabled \n
*                                     4 : Compare logic analog value >= compare value enabled \n
*                                     5 : Compare logic analog value <= compare value enabled \n
* @param[in]  d_CompareLevelAValue : Level A compare value
* @param[in]  b_CompareLevelBMode  : Level B compare mode: \n
*                                     0 : Compare logic disabled \n
*                                     1 : Compare logic analog value = compare value enabled \n
*                                     2 : Compare logic analog value > compare value enabled \n
*                                     3 : Compare logic analog value < compare value enabled \n
*                                     4 : Compare logic analog value >= compare value enabled \n
*                                     5 : Compare logic analog value <= compare value enabled \n
* @param[in]  d_CompareLevelBValue : Level B compare value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number \n
*         -3: Channel not initialised \n
*         -4: Functionality not available \n
*         -5: Wrong compare level A \n
*         -6: Wrong compare value A \n
*         -7: Wrong compare level B \n
*         -8: Wrong compare value B \n
*         -9: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputInitCompareLogic (DWORD_ dw_BoardHandle,
                                             BYTE_   b_Channel,
                                             BYTE_   b_CompareLevelAMode,
                                             DOUBLE  d_CompareLevelAValue,
											 BYTE_   b_CompareLevelBMode,
                                             DOUBLE  d_CompareLevelBValue);


/*i_PCI3009_AnalogInputEnableDisableCompareLogic*/
/** Enable or disable the compare logic from all channels
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in]  b_CompareLogicFlag   : Enable/disable compare logic flag \n
*                                     PCI3009_DISABLE : Disable the compare logic \n
*                                     PCI3009_ENABLE  : Enable the compare logic
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong compare logic flag
*/
_INT_ i_PCI3009_AnalogInputEnableDisableCompareLogic (DWORD_ dw_BoardHandle,
                                                      BYTE_   b_CompareLogicFlag);


/*i_PCI3009_AnalogInputGetSingleCompareLogicStates*/
/** Get the selected compare logic channel state
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in]  b_Channel            : Channel number of the input to be get the compare state
*
* @param[out]  pb_CompareLogicStates : Compare logic state. \n
*                                       D0 : 0 -> Compare level A not occur \n
*                                            1 -> Compare level A occur \n
*                                       D1 : 0 -> Compare level B not occur \n
*                                            1 -> Compare level B occur
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number \n
*         -3: Channel not initialised \n
*         -4: Compare logic not enabled \n
*         -5: No conversion started
*/
_INT_ i_PCI3009_AnalogInputGetSingleCompareLogicStates (DWORD_ dw_BoardHandle,
                                                        BYTE_   b_Channel,
                                                        PBYTE_ pb_CompareLogicStates);


/*i_PCI3009_AnalogInputGetAllCompareLogicStates*/
/** Get all compare logic channels state
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @param[out]  pdw_CompareLogicStates : Compare logic state. \n
*                                        D0 : 0 -> Channel 0 compare level A not occur \n
*                                             1 -> Channel 0 compare level A occur \n
*                                        D1 : 0 -> Channel 0 compare level B not occur \n
*                                             1 -> Channel 0 compare level B occur \n
*                                        . \n
*                                        . \n
*                                        . \n
*                                        D30: 0 -> Channel 15 compare level A not occur \n
*                                             1 -> Channel 15 compare level A occur \n
*                                        D31: 0 -> Channel 15 compare level B not occur \n
*                                             1 -> Channel 15 compare level B occur
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Compare logic not enabled \n
*         -3: No conversion started
*/
_INT_ i_PCI3009_AnalogInputGetAllCompareLogicStates (DWORD_   dw_BoardHandle,
                                                     PDWORD_ pdw_CompareLogicStates);



/*i_PCI3009_AnalogInputGetSingleCompareLogicStates*/
/** Get the selected auto refresh compare logic channel status. For this start the auto refresh
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in]  b_Channel            : Channel number of the input to be get the compare state
* @param[in]  dw_StructSize        : str_AutoRefreshDataPackage struct size (sizeof(str_AutoRefreshDataPackage))
*
* @param[out]  ps_AutoRefreshDataPackage : str_AutoRefreshDataPackage, return the analog value and the compare states. \n
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong channel number \n
*         -3: Channel not initialised \n
*         -4: Wrong ps_AutoRefreshDataPackage struct size
*         -5: Compare logic not enabled \n
*         -6: No conversion started
*/
_INT_ i_PCI3009_AnalogInputGetAutoRefreshCompareLogicStates (DWORD_                      dw_BoardHandle,
                                                             BYTE_                        b_Channel,
                                                             pstr_AutoRefreshDataPackage ps_AutoRefreshDataPackage,
                                                             DWORD_                      dw_StructSize);

/* @} */

/** \defgroup PCI3009_ANA_INP_TRIGGER PCI-3009 analog input trigger functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/*i_PCI3009_AnalogInputEnableDisableHardwareTrigger*/
/** Enable/disable the hardware trigger action. \n
* The user have the posibility via b_HardwareTriggerAction to define the action to make
*
* @param[in] dw_BoardHandle               : Handle of board PCI-3009
* @param[in]  b_HardwareTriggerAction     : Trigger action selection \n
*                                           PCI3009_DISABLE : \n
*                                           Disable the hardware trigger action \n
*                                           PCI3009_ONE_SHOT_TRIGGER : \n
*                                           After the first dw_HardwareTriggerCount trigger the conversion are started. \n
*                                           All next trigger have not effect. \n
*                                           The trigger are rearmed after the next call from the function \n
*                                           "i_PCI3009_AnalogInputRead1Channel" or \n
*                                           "i_PCI3009_AnalogInputReadMoreChannels" or \n
*                                           "i_PCI3009_AnalogInputStartAutoRefresh" or \n
*                                           "i_PCI3009_AnalogInputStartSequence" \n
*                                           PCI3009_TRIGGER_START_A_SERIES: \n
*                                           After each dw_HardwareTriggerCount trigger a series of dw_HardwareTriggerCycleCount acqisition cycles is started. \n
*											Only available for sequence and auto refresh
* @param[in]  b_HardwareTriggerLevel      : PCI3009_LOW_FRONT: \n
*                                           If the hardware trigger is ued, it triggers from "1" to "0" \n
*                                           PCI3009_HIGH_FRONT: \n
*                                           If the hardware trigger is used, it triggers from "0" to "1" \n
*                                           PCI3009_HIGH_LOW_FRONT: \n
*                                           If the hardware trigger is used, it triggers from "0" to "1" or from "1" to "0"
* @param[in] dw_HardwareTriggerCount      : Hardware trigger counter. Define the number of trigger events before the action occur (> 0 and < 65536)
* @param[in] dw_HardwareTriggerCycleCount : Define the number of sequences or auto refresh cycles to trigger.
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: Wrong hardware trigger action selection \n
*         -3: Wrong hardware trigger level selection \n
*         -4: Wrong hardware trigger count value \n
*         -5: Wrong trigger cycle count value \n
*         -6: A conversion is already started
*/
_INT_ i_PCI3009_AnalogInputEnableDisableHardwareTrigger (DWORD_ dw_BoardHandle,
                                                         BYTE_   b_HardwareTriggerAction,
                                                         BYTE_   b_HardwareTriggerLevel,
														 DWORD_ dw_HardwareTriggerCount,
                                                         DWORD_ dw_HardwareTriggerCycleCount);


/*i_PCI3009_AnalogInputGetHardwareTriggerStatus*/
/** Returns the status (occur or not), the state from input (active or not) and the number of that fail before the next trigger occur
*
* @param[in]  dw_BoardHandle              : Handle of board PCI-3009
*
* @param[out] pb_HardwareTriggerAction    : Trigger action selection \n
*                                           PCI3009_DISABLE : \n
*                                           Disable the hardware trigger action \n
*                                           PCI3009_ONE_SHOT_TRIGGER : \n
*                                           After the first dw_HardwareTriggerCount trigger the conversion are started. \n
*                                           All next trigger have not effect. \n
*                                           The trigger are rearmed after the next call from the function \n
*                                           "i_PCI3009_AnalogInputRead1Channel" or \n
*                                           "i_PCI3009_AnalogInputReadMoreChannels" or \n
*                                           "i_PCI3009_AnalogInputStartAutoRefresh" or \n
*                                           "i_PCI3009_AnalogInputStartSequence" \n
*                                           PCI3009_TRIGGER_START_A_SERIES: \n
*                                           After each dw_HardwareTriggerCount trigger a series of dw_HardwareTriggerCycleCount acqisition cycles is started. \n
*											Only available for sequence and auto refresh
* @param[out]  pb_HardwareTriggerStatus   : 0: Hardware trigger did not occur \n
*                                           1: Hardware trigger occurred
* @param[out] pdw_HardwareTriggerCount    : Number of pulse that fail before the next trigger occur
* @param[out]  pb_HardwareTriggerState    : 0: Hardware trigger input is not active (Low state) \n
*                                           1: Hardware trigger input is active (High state)
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong
*/
_INT_ i_PCI3009_AnalogInputGetHardwareTriggerStatus (DWORD_   dw_BoardHandle,
                                                     PBYTE_   pb_HardwareTriggerAction,
                                                     PBYTE_   pb_HardwareTriggerStatus,
													 PDWORD_ pdw_HardwareTriggerCount,
													 PBYTE_   pb_HardwareTriggerState);


/* @} */


/** \defgroup PCI3009_ANA_INP_POTIS PCI-3009 calibration potentiometer functions
* \ingroup PCI3009_ANA_INP
* @{
*/

/**
 * Read the value of the potentiometer
 * @param[in] dw_BoardHandle Handle of PCI-3009 board
 * @param[in] b_PotisCs Poti chip select \n
 * 			000: ADC0 offset (bipolar) \n
 * 			001: ADC1 offset (bipolar) \n
 * 			010: ADC0 gain   (bipolar) \n
 * 			011: ADC1 gain   (bipolar) \n
 * 			100: ADC2 offset (unipolar) \n
 * 			101: ADC2 gain   (unipolar) \n
 * 			110: Analog output +10V reference \n
 * 			111: Analog output -10V reference \n
 * @param[out] pdw_Value Value of the selected potentiometer
 * @return  0: No error \n
 *         -1: The board handle parameter is wrong \n
 *         -2: Calibrating this board is not allowed \n
 */
_INT_ i_PCI3009_ReadPotis(DWORD_ dw_BoardHandle, BYTE_ b_PotisCs, PDWORD_ pdw_Value);

/**
 * Write the value of the potentiometer
 * @param[in] dw_BoardHandle Handle of PCI-3009 board
 * @param[in] b_PotisCs Poti chip select \n
 * 			000: ADC0 offset (bipolar) \n
 * 			001: ADC1 offset (bipolar) \n
 * 			010: ADC0 gain   (bipolar) \n
 * 			011: ADC1 gain   (bipolar) \n
 * 			100: ADC2 offset (unipolar) \n
 * 			101: ADC2 gain   (unipolar) \n
 * 			110: Analog output +10V reference \n
 * 			111: Analog output -10V reference \n
 * @param[out] dw_Value Value of the selected potentiometer
 * @return  0: No error \n
 *         -1: The board handle parameter is wrong \n
 *         -2: Calibrating this board is not allowed \n
 */
_INT_ i_PCI3009_WritePotis(DWORD_ dw_BoardHandle, BYTE_ b_PotisCs, DWORD_ dw_Value);

/**
 * Save the value of all the potentiometers in the EEPROM
 * @param[in] dw_BoardHandle Handle of PCI-3009 board
 * @return  0: No error \n
 *         -1: The board handle parameter is wrong \n
 *         -2: Calibrating this board is not allowed \n
 */
_INT_ i_PCI3009_SavePotis(DWORD_ dw_BoardHandle);

/* @} */

/* @} */


/** \defgroup PCI3009_MODULE PCI-3009 module functions
* \ingroup PCI3009
* @{
*/

/** \defgroup PCI3009_PL PCI-3009 programming logic functions
* \ingroup PCI3009_PL
* @{
*/

/** \defgroup PCI3009_PL_PROGRAMM PCI-3009 Programming logic program function
* \ingroup PCI3009_PL
* @{
*/

/** Configure the programmable module.
 * 
 * The right version of the RBF file has to be used \n
 * according to the CPCI-3009 hardware revision. \n
 * See the exemple programm. \n
 *
 * @param[in] dw_BoardHandle    : Handle of board PCI-3009
 * @param[in] pc_rbfPath		: RBF file path.
 *
 * @retval 0: No error.
 * @retval -1: IOCTL error.
 * @retval -2: Timeout.
 * @retval -3: Readback error.
 * @retval -4: The computer must be restarted to complete the programmation.
 * @retval -5: Busy.
 * @retval -6: Open RBF file error.
 * @retval -7: RBF file size error.
 * @retval -8: Memory allocation error.
 */
_INT_ i_PCI3009_PLFimrwareConfigure(DWORD_ dw_BoardHandle, PCHAR_ pc_rbfPath);

/* @} */

/** \defgroup PCI3009_PL_INFO PCI-3009 Programming logic information functions
* \ingroup PCI3009_PL
* @{
*/

/** Get the programmable module revision.
 * 
 * @param[in] dw_BoardHandle    : Handle of board PCI-3009
 * @param[out] pdw_Revision		: Module revision.
 *
 * @retval 0: No error.
 * @retval -1: IOCTL error.
 */
_INT_ i_PCI3009_PLFimrwareRevision(DWORD_ dw_BoardHandle, PDWORD_ pdw_Revision);

/** Get the programmable module functionality.
 * 
 * @param[in] dw_BoardHandle		: Handle of board PCI-3009
 * @param[out] pdw_Functionality	: Module functionality.
 *
 * @retval 0: No error.
 * @retval -1: IOCTL error.
 */
_INT_ i_PCI3009_PLFimrwareFunctionality (DWORD_   dw_BoardHandle, PDWORD_ pdw_Functionality);

/* @} */

/* @} */

/** \defgroup PCI3009_DIG PCI-3009 digital I/O functions
* \ingroup PCI3009_MODULE
* @{
*/

/** \defgroup PCI3009_DIG_INIT PCI-3009 digital I/O initialisation functions
* \ingroup PCI3009_DIG
* @{
*/

/*i_PCI3009_InitDigitalIO */
/** Configure the digital I/O operating.
* You must calling this function be for you call any other function witch \n
* access of digital I/O.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in]  b_ChannelAMode : Channel A mode selection
*                              0 : Channel used for digital input
*                              0 : Channel used for digital output
* @param[in]  b_ChannelBMode : Channel B mode selection
*                              0 : Channel used for digital input
*                              0 : Channel used for digital output
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Bi-directional channel A configuration error \n
*         -4: Bi-directional channel B configuration error \n
*/

_INT_    i_PCI3009_InitDigitalIO    (DWORD_  dw_BoardHandle,
                                     BYTE_    b_ChannelAMode,
                                     BYTE_    b_ChannelBMode);

/* @} */

/** \defgroup PCI3009_DIG_INP PCI-3009 digital I/O input functions
* \ingroup PCI3009_DIG
* @{
*/


/*i_PCI3009_ReadDigitalIOChlValue*/
/** Read the status from selected digital I/O digital input (b_InputChannel)
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in]  b_InputChannel : Selection from digital input (0 to 6)\n
*                               0 : Channel C \n
*                               1 : Channel D \n
*                               2 : Channel E \n
*                               3 : Channel F \n
*                               4 : Channel G \n
*                               5 : Channel A \n
*                               6 : Channel B \n
* @param[out] pb_ChannelStatus : Return the current selected channel status
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*         -4: The selected digital I/O digital input is wrong \n
*         -5: The digital channel A is used for output \n
*         -6: The digital channel B is used for output \n
*/

_INT_    i_PCI3009_ReadDigitalIOChlValue      (DWORD_  dw_BoardHandle,
                                               BYTE_    b_InputChannel,
                                               PBYTE_  pb_ChannelStatus);

/*i_PCI3009_ReadDigitalIOPortValue*/
/** Read the status from digital input port
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[out] pb_PortValue   : Digital I/O inputs port status
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*/

_INT_    i_PCI3009_ReadDigitalIOPortValue  (DWORD_   dw_BoardHandle,
                                            PBYTE_   pb_PortValue);

/* @} */

/** \defgroup PCI3009_DIG_OUT PCI-3009 digital I/O output functions
* \ingroup PCI3009_DIG
* @{
*/

/*i_PCI3009_SetDigitalIOMemoryOn*/
/** Activates the digital output memory. After having \n
* called up this function, the output you have previously \n
* activated with the function"i_PCI3009_SetDigitalIOOutputXOn" are not reset.\n
* You can reset them with the function \n
* "i_PCI3009_SetDigitalIOOutputXOff".
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*/

_INT_    i_PCI3009_SetDigitalIOMemoryOn (DWORD_ dw_BoardHandle);

/*i_PCI3009_SetDigitalIOMemoryOff*/
/** Deactivates the digital output memory
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*/

_INT_    i_PCI3009_SetDigitalIOMemoryOff (DWORD_ dw_BoardHandle);

/*i_PCI3009_SetDigitalIOChlOn*/
/** Sets the output witch has been passed with the \n
* parameter b_Channel. Setting an output means setting an ouput high
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_OutputChannel : Selection from digital output channel (0 to 2) \n
*                              0 : Channel H \n
*                              1 : Channel A \n
*                              2 : Channel B
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*         -4: The selected digital output is wrong \n
*         -5: The digital channel A is used for input \n
*         -6: The digital channel B is used for input
*/

_INT_    i_PCI3009_SetDigitalIOChlOn    (DWORD_ dw_BoardHandle,
                                         BYTE_   b_OutputChannel);

/*i_PCI3009_SetDigitalIOChlOff*/
/** Resets the output witch has been passed with the \n
* parameter b_Channel. Resetting an output means setting an ouput low.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_OutputChannel : Selection from digital output channel (0 to 2) \n
*                              0 : Channel H \n
*                              1 : Channel A \n
*                              2 : Channel B
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*         -4: The selected digital output is wrong \n
*         -5: The digital channel A is used for input \n
*         -6: The digital channel B is used for input \n
*         -7: Digital Output Memory OFF. \n
*             Use previously the function "i_PCI3009_SetDigitalIOMemoryOn".
*/

_INT_    i_PCI3009_SetDigitalIOChlOff   (DWORD_ dw_BoardHandle,
                                         BYTE_   b_OutputChannel);

/*i_PCI3009_SetDigitalIOPortOn*/
/** Sets one or several outputs from port. \n
* Setting an output means setting an output high. \n
* If you have switched OFF the digital output memory (OFF), all the other output are set to "0".
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_PortValue     : Output Value ( 0 To 7 )
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*         -4: Output value wrong \n
*         -5: The digital channel A is used for input \n
*         -6: The digital channel B is used for input
*/

_INT_    i_PCI3009_SetDigitalIOPortOn   (DWORD_ dw_BoardHandle,
                                         BYTE_   b_PortValue);


/*i_PCI3009_SetDigitalIOPortOff*/
/** Resets one or several output from port. Resetting means setting low.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_PortValue     : Output Value ( 0 To 7 )
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a digital I/O module \n
*         -3: Digital I/O not initialised \n
*         -4: Output value wrong \n
*         -5: The digital channel A is used for input \n
*         -6: The digital channel B is used for input
*         -7: Digital Output Memory OFF. \n
*             Use previously the function "i_PCI3009_SetDigitalIOMemoryOn".
*/

_INT_    i_PCI3009_SetDigitalIOPortOff  (DWORD_ dw_BoardHandle,
                                         BYTE_   b_PortValue);


/* @} */

/* @} */


/** \defgroup PCI3009_SSI PCI-3009 SSI functions
* \ingroup PCI3009_MODULE
* @{
*/


/** \defgroup PCI3009_SSI_FORMATED PCI-3009 SSI formated tram formated functions
* \ingroup PCI3009_SSI
* @{
*/

/*i_PCI3009_InitSSI*/
/** Configure the SSI operating mode. \n
* You must calling this function be for you call any other function witch access of SSI.
*
* @param[in] dw_BoardHandle       : Handle of board PCI-3009
* @param[in] b_SSIProfile         : Selection from SSI profile length (1 to 32).
* @param[in] b_PositionTurnLength : Selection from SSI position data length (1 to 31).
* @param[in] b_TurnCptLength      : Selection from SSI turn counter data length (0 to 31).
* @param[in] dw_SSIOutputClock    : Selection from SSI output clock. \n
*                                   From  252 to 5 000 000 Hz
* @param[in] b_SSICountingMode    : SSI counting mode selection \n
*                                   - PCI3009_BINARY_MODE : \n
*                                     Binary counting mode. \n
*                                   - PCI3009_GRAY_MODE : \n
*                                     Gray counting mode. \n
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: The selected SSI profile length is wrong \n
*         -4: The selected SSI position data length is wrong \n
*         -5: The selected SSI turn counter data length is wrong \n
*         -6: The selected SSI output clock is wrong \n
*         -7: The selected SSI counting mode parameter is wrong
*/
_INT_    i_PCI3009_InitSSI      (DWORD_  dw_BoardHandle,
                                 BYTE_    b_SSIProfile,
                                 BYTE_    b_PositionTurnLength,
                                 BYTE_    b_TurnCptLength,
                                 DWORD_  dw_SSIOutputClock,
                                 BYTE_    b_SSICountingMode);


/*i_PCI3009_Read1SSIValue*/
/** Read the selected SSI counter (b_SelectedSSI)
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_SelectedSSI       : Selection from SSI counter (0 to 2)
*
* @param[out] pdw_Position       : SSI position in the turn
* @param[out] pdw_TurnCpt        : Number of turns
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: The selected SSI is wrong \n
*         -5: This function does not support more than 32 bits profile length
*/

_INT_    i_PCI3009_Read1SSIValue        (DWORD_   dw_BoardHandle,
                                         BYTE_     b_SelectedSSI,
                                         PDWORD_ pdw_Position,
                                         PDWORD_ pdw_TurnCpt);



/*i_PCI3009_ReadAllSSIValue*/
/** Read all SSI counter
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @param[out] pdw_Position       : SSI position in the turn
* @param[out] pdw_TurnCpt        : Number of turns
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: This function does not support more than 32 bits profile length
*/

_INT_    i_PCI3009_ReadAllSSIValue      (DWORD_   dw_BoardHandle,
                                         PDWORD_ pdw_Position,
                                         PDWORD_ pdw_TurnCpt);

/* @} */

/** \defgroup PCI3009_SSI_RAW PCI-3009 SSI raw data functions
* \ingroup PCI3009_SSI
* @{
*/


/*i_PCI3009_InitSSIRawData*/
/** Configure the SSI operating mode. \n
* You must calling this function be for you call any other function witch access of SSI.
*
* @param[in] dw_BoardHandle       : Handle of board PCI-3009
* @param[in] b_SSIProfile         : Selection from SSI profile length (1 to 49).
* @param[in] dw_SSIOutputClock    : Selection from SSI output clock. \n
*                                   From  252 to 5 000 000 Hz
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: The module does not support this profile length \n
*         -4: The selected SSI profile length is wrong \n
*         -5: The selected SSI output clock is wrong
*/


_INT_    i_PCI3009_InitSSIRawData      (DWORD_  dw_BoardHandle,
                                        BYTE_    b_SSIProfile,
                                        DWORD_  dw_SSIOutputClock);

/*i_PCI3009_Read1SSIRawDataValue*/
/** Read the selected SSI counter (b_SelectedSSI)
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_SelectedSSI       : Selection from SSI counter (0 to 2)
* @param[in] b_ValueArraySize    : Size of the pdw_ValueArray in dword 
*
* @param[out] pdw_ValueArray     : Array of the raw data from the SSI counter
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: The selected SSI is wrong \n
*         -5: The b_ValueArraySize parameter is wrong
*/

_INT_    i_PCI3009_Read1SSIRawDataValue        (DWORD_   dw_BoardHandle,
                                                BYTE_     b_SelectedSSI,
                                                PDWORD_ pdw_ValueArray,                     
                                                BYTE_     b_ValueArraySize);

/*i_PCI3009_ReadAllSSIRawDataValue*/
/** Read all SSI counter
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_ValueArraySize    : Size of the pdw_ValueArray in dword
*
* @param[out] pdw_ValueArray     : Array of the raw data from the SSI counter
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: The b_ValueArraySize parameter is wrong
*/

_INT_    i_PCI3009_ReadAllSSIRawDataValue  (DWORD_   dw_BoardHandle,
                                            PDWORD_ pdw_ValueArray,                     
                                            BYTE_     b_ValueArraySize);

/*i_PCI3009_StartSSIAcquisition*/
/** Start the SSI acquisition
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: Acquisition already in progress
*/

_INT_    i_PCI3009_StartSSIAcquisition  (DWORD_ dw_BoardHandle);

/*i_PCI3009_GetSSIAcquisitionStatus*/
/** Return the SSI acquisition status
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @param[out] pb_Status          : 1 Acquisition in progress \n
*                                  0 Acquisition beend
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI"
*/

_INT_    i_PCI3009_GetSSIAcquisitionStatus  (DWORD_   dw_BoardHandle,
                                             PBYTE_   pb_Status);

/*i_PCI3009_GetSSIValue*/
/** Read the selected SSI counter
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_SelectedSSI       : Selection from SSI counter (0 to 2)
*
* @param[out] pdw_Position       : SSI position in the turn
* @param[out] pdw_TurnCpt        : Number of turns
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: The selected SSI is wrong \n
*         -5: Acquisition in progress \n
*         -6: This function does not support more than 32 bits profile length
*/

_INT_    i_PCI3009_GetSSIValue        (DWORD_   dw_BoardHandle,
                                       BYTE_     b_SelectedSSI,
                                       PDWORD_ pdw_Position,
                                       PDWORD_ pdw_TurnCpt);

/*i_PCI3009_GetSSIRawDataValue*/
/** Read the selected SSI counter
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_SelectedSSI       : Selection from SSI
* @param[in] b_ValueArraySize    : Size of the pdw_ValueArray in dword
*
* @param[out] pdw_ValueArray     : Array of the raw data from the SSI counter
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: SSI not initialised see function "i_PCI3009_InitSSI" \n
*         -4: The selected SSI is wrong \n
*         -5: Acquisition in progress \n
*         -6: The b_ValueArraySize parameter is wrong
*/

_INT_    i_PCI3009_GetSSIRawDataValue        (DWORD_   dw_BoardHandle,
                                              BYTE_     b_SelectedSSI,
                                              PDWORD_ pdw_ValueArray,                     
                                              BYTE_     b_ValueArraySize);


/* @} */


/** \defgroup PCI3009_SSI_DIG_INP PCI-3009 SSI digital input functions
* \ingroup PCI3009_SSI
* @{
*/


/*i_PCI3009_ReadSSI1DigitalInput*/
/** Read the status from selected SSI digital input (b_InputChannel)
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
* @param[in] b_InputChannel      : Selection from digital input (0 to 2)
*
* @param[out] pb_ChannelStatus   : Digital input channel status \n
*                                  0 : Channle is not active \n
*                                  1 : Channle is active
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module \n
*         -3: The selected SSI digital input is wrong
*/

_INT_    i_PCI3009_ReadSSI1DigitalInput  (DWORD_  dw_BoardHandle,
                                          BYTE_    b_InputChannel,
                                          PBYTE_  pb_ChannelStatus);

/*i_PCI3009_ReadSSIAllDigitalInput*/
/** Read the status from all SSI digital inputs
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @param[out] pb_InputStatus     : Digital inputs channel status
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module
*/

_INT_    i_PCI3009_ReadSSIAllDigitalInput  (DWORD_   dw_BoardHandle,
                                            PBYTE_   pb_InputStatus);

/* @} */


/** \defgroup PCI3009_SSI_DIG_OUT PCI-3009 SSI digital output functions
* \ingroup PCI3009_SSI
* @{
*/

/*i_PCI3009_SetSSIDigitalOutputOn*/
/** Set the digital output ON
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module
*/

_INT_    i_PCI3009_SetSSIDigitalOutputOn  (DWORD_ dw_BoardHandle);


/*i_PCI3009_SetSSIDigitalOutputOff*/
/** Set the digital output OFF
*
* @param[in] dw_BoardHandle      : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a SSI module
*/

_INT_    i_PCI3009_SetSSIDigitalOutputOff  (DWORD_ dw_BoardHandle);

/* @} */


/* @} */

/** \defgroup PCI3009_INC_CPT PCI-3009 incremental counter functions
* \ingroup PCI3009_MODULE
* @{
*/

/** \defgroup PCI3009_INC_CPT_INIT PCI-3009 incremental counter initialisation functions
* \ingroup PCI3009_INC_CPT
* @{
*/


/*i_PCI3009_InitCounter*/
/** Configure the counter operating mode \n
* You must calling this function be for you call any other function witch access of counters. \n\n
*                                       
*                          <b>Counter range</b>\n
* <table>
*    <tr>
*       <td>Parameter</td>
*       <td>Passed value</td>
*       <td>Description</td>
*    </tr>
*    <tr>
*       <td>b_CounterRange</td>
*       <td>PCI3009_16BIT_COUNTER</td>
*       <td> The module is configured for two 16-bit counter.<br>
*             - b_FirstCounterModus and b_FirstCounterOption <br>
*               configure the first 16 bit counter.<br>
*             - b_SecondCounterModus and b_SecondCounterOption <br>
*               configure the second 16 bit counter.
*       </td>
*    </tr>
*    <tr>
*       <td>b_CounterRange</td>
*       <td>PCI3009_32BIT_COUNTER</td>
*       <td> The module is configured for one 32-bit counter.<br>
*             - b_FirstCounterModus and b_FirstCounterOption <br>
*               configure the 32 bit counter.<br>
*             - b_SecondCounterModus and b_SecondCounterOption <br>
*               are not used and have no importance.
*       </td>
*    </tr>
* </table>
*\n
*                      <b>Counter operating mode</b>\n
* <table>
*    <tr>
*       <td>Parameter</td>
*       <td>Passed value</td>
*       <td>Description</td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterModus or b_SecondCounterModus</td>
*       <td>PCI3009_QUADRUPLE_MODE</td>
*       <td> In the quadruple mode, the edge analysis circuit generates a
*            counting pulse from each edge of 2 signals which are phase shifted
*            in relation to each other.
*       </td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterModus or b_SecondCounterModus</td>
*       <td>PCI3009_DOUBLE_MODE</td>
*       <td> Functions in the same way as the quadruple mode, except that only
*            two of the four edges are analysed per period
*       </td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterModus or b_SecondCounterModus</td>
*       <td>PCI3009_SIMPLE_MODE</td>
*       <td> Functions in the same way as the quadruple mode, except that only
*            one of the four edges is analysed per period.
*       </td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterModus or b_SecondCounterModus</td>
*       <td>PCI3009_DIRECT_MODE</td>
*       <td> In the direct mode the both edge analysis circuits are inactive.
*            The inputs A, B in the 32-bit mode or A, B and C, D in the 16-bit mode 
*            represent, each, one clock pulse gate circuit. There by frequency and
*            pulse duration measurements can be performed.
*       </td>
*    </tr>
* </table>
*\n
* <b>IMPORTANT!\n
* If you have configured the module for two 16-bit counter, a mixed \n
* mode with a counter in quadruple/double/single mode \n
* and the other counter in direct mode is not possible!</b> \n
* \n
* <b>Counter operating option for quadruple/double/simple mode</b>
* <table>
*    <tr>
*       <td>Parameter</td>
*       <td>Passed value</td>
*       <td>Description</td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterOption or b_SecondCounterOption</td>
*       <td>PCI3009_HYSTERESIS_ON</td>
*       <td>In both edge analysis circuits is available one hysteresis circuit.
*           It suppresses each time the first counting pulse after a change
*           of rotation.
*       </td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterOption or b_SecondCounterOption</td>
*       <td>PCI3009_HYSTERESIS_OFF</td>
*       <td>The first counting pulse is not suppress after a change of rotation.</td>
*    </tr>
* </table>
* \n
*
* <b>IMPORTANT!\n
* This option are only avaible if you have selected the direct mode.</b>
* \n\n
* <b>Counter operating option for direct mode</b>
* <table>
*    <tr>
*       <td>Parameter</td>
*       <td>Passed value</td>
*       <td>Description</td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterOption or b_SecondCounterOption</td>
*       <td>PCI3009_INCREMENT</td>
*       <td>The counter increment for each counting pulse</td>
*    </tr>
*    <tr>
*       <td>b_FirstCounterOption or b_SecondCounterOption</td>
*       <td>PCI3009_DECREMENT </td>
*       <td>The counter decrement for each counting pulse</td>
*    </tr>
* </table>
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in] b_CounterRange        : Selection form counter range.
* @param[in] b_FirstCounterModus   : First counter operating mode.
* @param[in] b_FirstCounterOption  : First counter  option.
* @param[in] b_SecondCounterModus  : Second counter operating  mode.
* @param[in] b_SecondCounterOption : Second counter  option.
*
* @return  0: 0: No error \n
*            -1: The handle parameter of the board is wrong \n
*            -2: The module is not a counter module \n
*            -3: The selected counter range is wrong. \n
*            -4: The selected first counter operating mode is wrong. \n
*            -5: The selected first counter operating option is wrong \n
*            -6: The selected second counter operating mode is wrong. \n
*            -7: The selected second counter operating option is wrong.
*/

_INT_    i_PCI3009_InitCounter (DWORD_        dw_BoardHandle,
                                BYTE_          b_CounterRange,
                                BYTE_          b_FirstCounterModus,
                                BYTE_          b_FirstCounterOption,
                                BYTE_          b_SecondCounterModus,
                                BYTE_          b_SecondCounterOption);



/*i_PCI3009_CounterAutoTest*/
/** A test mode is intended for testing the component and \n
* the connected periphery. All the 8-bit counter chains \n
* are operated internally as down counters. \n
* Independently from the external signals,\n
* all the four 8-bit counter chains are decremented in \n
* parallel by each negative clock pulse edge of CLKX.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
*
* @param[out] pb_TestStatus  : Auto test conclusion. \n
*                              0 : No error \n
*                              1 : Error
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module
*/

_INT_    i_PCI3009_CounterAutoTest      (DWORD_   dw_BoardHandle,
                                         PBYTE_   pb_TestStatus);

/*i_PCI3009_ClearCounterValue*/
/** Clear the counter value .                              |
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_ClearCounterValue    (DWORD_ dw_BoardHandle);


/*i_PCI3009_SetInputFilter*/
/** Disable or enable the software filter from selected b_Filter determine the filter time
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] b_Filter         : Filter selection\n\n
*
* <table>
*    <tr>
*       <td>b_Filter</td>
*       <td>Filter time</td>
*    </tr>
*    <tr>
*       <td>0</td>
*       <td>Disabled</td>
*    </tr>
*    <tr>
*       <td>1</td>
*       <td>100ns</td>
*    </tr>
*    <tr>
*       <td>2</td>
*       <td>150ns</td>
*    </tr>
*    <tr>
*       <td>3</td>
*       <td>200ns</td>
*    </tr>
*    <tr>
*       <td>4</td>
*       <td>250ns</td>
*    </tr>
*    <tr>
*       <td>5</td>
*       <td>300ns</td>
*    </tr>
*    <tr>
*       <td>6</td>
*       <td>350ns</td>
*    </tr>
*    <tr>
*       <td>7</td>
*       <td>400ns</td>
*    </tr>
*    <tr>
*       <td>8</td>
*       <td>450ns</td>
*    </tr>
*    <tr>
*       <td>9</td>
*       <td>500ns</td>
*    </tr>
*    <tr>
*       <td>10</td>
*       <td>550ns</td>
*    </tr>
*    <tr>
*       <td>11</td>
*       <td>600ns</td>
*    </tr>
*    <tr>
*       <td>12</td>
*       <td>650ns</td>
*    </tr>
*    <tr>
*       <td>13</td>
*       <td>700ns</td>
*    </tr>
*    <tr>
*       <td>14</td>
*       <td>750ns</td>
*    </tr>
*    <tr>
*       <td>15</td>
*       <td>800ns</td>
*    </tr>
* </table>
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected filter value is wrong
*/

_INT_    i_PCI3009_SetInputFilter       (DWORD_ dw_BoardHandle,
                                         BYTE_   b_Filter);

/* @} */


/** \defgroup PCI3009_INC_CPT_READ PCI-3009 incremental counter read functions
* \ingroup PCI3009_INC_CPT
* @{
*/


/*i_PCI3009_LatchCounter*/
/** Latch the courant value in to the selected latch register (b_LatchReg).
*
* @param[in] dw_BoardHandle : Handle of board PCI-3009
* @param[in] b_LatchReg     : Selected latch register \n
*                               0 : for the first latch register \n
*                               1 : for the second latch register
** @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected latch register parameter is wrong
*/

_INT_    i_PCI3009_LatchCounter (DWORD_ dw_BoardHandle,
                                 BYTE_   b_LatchReg);


/*i_PCI3009_ReadLatchRegisterStatus*/
/** Read the latch register status from selected latch register (b_LatchReg).
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_LatchReg      : Selected latch register \n
*                               0 : for the first latch register \n
*                               1 : for the second latch register
*
* @param[out] pb_LatchStatus : Latch register status.\n
*                                 0 : No latch occur \n
*                                 1 : A software latch occur \n
*                                 2 : A hardware latch occur \n
*                                 3 : A software and hardware latch occur 
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected latch register parameter is wrong
*/

_INT_    i_PCI3009_ReadLatchRegisterStatus      (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_LatchReg,
                                                 PBYTE_ pb_LatchStatus);


/*i_PCI3009_ReadLatchRegisterValue*/
/** Read the latch register value from selected latch register (b_LatchReg).
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in] b_LatchReg      : Selected latch register
*                               0 : for the first latch register \n
*                               1 : for the second latch register \n
*
* @param[out] pdw_LatchValue : Latch register value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected latch register parameter is wrong
*/

_INT_    i_PCI3009_ReadLatchRegisterValue       (DWORD_   dw_BoardHandle,
                                                 BYTE_     b_LatchReg,
                                                 PDWORD_ pdw_LatchValue);


/*i_PCI3009_EnableLatchInterrupt*/
/** Enable the latch interrupt. Each software or hardware latch occur a interrupt.
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Interrupt routine not installed see function "i_PCI3009_SetBoardIntRoutine"
*
*/

_INT_    i_PCI3009_EnableLatchInterrupt (DWORD_ dw_BoardHandle);


/*i_PCI3009_DisableLatchInterrupt*/
/** Disable the latch interrupt
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_DisableLatchInterrupt        (DWORD_ dw_BoardHandle);

/*i_PCI3009_Read16BitCounterValue */
/** Latch the selected 16-Bit counter (b_SelectedCounter) in to the first latch register and return the \n
* latched value.
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_SelectedCounter : Selected 16-Bit counter (0 or 1)
*
* @param[out] pw_CounterValue : 16-Bit counter value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected 16-Bit counter parameter is wrong
*/

_INT_    i_PCI3009_Read16BitCounterValue        (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_SelectedCounter,
                                                 PWORD_ pw_CounterValue);

/*i_PCI3009_Read32BitCounterValue*/
/** Latch the 32-Bit counter in to the first latch register and return the latched value.
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pdw_CounterValue : 32-Bit counter value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_Read32BitCounterValue        (DWORD_    dw_BoardHandle,
                                                 PDWORD_  pdw_CounterValue);



/* @} */

/** \defgroup PCI3009_INC_CPT_WRITE PCI-3009 incremental counter write functions
* \ingroup PCI3009_INC_CPT
* @{
*/

/*i_PCI3009_Write16BitCounterValue*/
/** Write a 16-Bit value (ui_WriteValue) in to the selected 16-Bit counter (b_SelectedCounter)
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_SelectedCounter : Selected 16-Bit counter (0 or 1)
* @param[in] w_WriteValue      : 16-Bit write value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The selected 16-Bit counter parameter is wrong
*/

_INT_    i_PCI3009_Write16BitCounterValue       (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_SelectedCounter,
                                                 WORD_   w_WriteValue);


/*i_PCI3009_Write32BitCounterValue*/
/** Write a 32-Bit value (ui_WriteValue)
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] dw_WriteValue    : 32-Bit write value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_Write32BitCounterValue       (DWORD_ dw_BoardHandle,
                                                 DWORD_ dw_WriteValue);


/* @} */

/** \defgroup PCI3009_INC_CPT_INDEX PCI-3009 incremental counter index functions
* \ingroup PCI3009_INC_CPT
* @{
*/

/*i_PCI3009_InitIndex*/
/** Initialise the index.\n
* If a INDEX flag occur, you have the possibility to clear the 32-Bit counter or to latch \n
* the current 32-Bit value in to the first latch register. The b_IndexOperation parameter \n
* give the possibility to choice the INDEX action. If you have enabled the automatic mode, \n
* each INDEX action is cleared automatically, else you must read the index status \n
* ("i_PCI3009_ReadIndexStatus") after each INDEX action.\n\n
*
* <table>
*    <tr>
*       <td>b_IndexOperation</td>
*       <td>Operation</td>
*    </tr>
*    <tr>
*       <td>PCI3009_HIGH_EDGE_CLEAR_COUNTER</td>
*       <td>After a high edge index signal, the counter value is cleared (32-Bit) </td>
*    </tr>
*    <tr>
*       <td>PCI3009_HIGH_EDGE_LATCH_COUNTER</td>
*       <td>After a high edge index signal, the counter value (32-Bit) is latched in to
*           the first latch register
*       </td>
*    </tr>
*    <tr>
*       <td>PCI3009_LOW_EDGE_CLEAR_COUNTER</td>
*       <td>After a low edge index signal, the counter value is cleared (32-Bit) </td>
*    </tr>
*    <tr>
*       <td>PCI3009_LOW_EDGE_LATCH_COUNTER</td>
*       <td>After a low edge index signal, the counter value (32-Bit) is latched in to
*           the first latch register
*       </td>
*    </tr>
*    <tr>
*       <td>PCI3009_HIGH_EDGE_LATCH_AND_CLEAR_COUNTER</td>
*       <td>After a high edge index signal, the counter value (32-Bit) is latched in to
*           the first latch register and ceared after this
*       </td>
*    </tr>
*    <tr>
*       <td>PCI3009_LOW_EDGE_LATCH_AND_CLEAR_COUNTER</td>
*       <td>After a low edge index signal, the counter value (32-Bit) is latched in to
*           the first latch register and ceared after this
*       </td>
*    </tr>
* </table>
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_ReferenceAction : Determine if the reference must set or no for the acceptance from index \n
*                                  PCI3009_ENABLE  : Reference must be set for accepted the index \n
*                                  PCI3009_DISABLE : Reference have not importance 
* @param[in] b_IndexOperation  : Index operating mode. See table. 
* @param[in] b_AutoMode        : Enable or disable the automatic index reset. \n
*                                  PCI3009_ENABLE  : Enable the automatic mode \n
*                                  PCI3009_DISABLE : Disable the automatic mode
* @param[in] b_InterruptEnable : Enable or disable the interrupt. \n
*                                  PCI3009_ENABLE  : Enable the interrupt \n
*                                  PCI3009_DISABLE : Disable the interrupt
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4  The reference action parameter is wrong \n
*         -5: The index operating mode parameter is wrong \n
*         -6: The auto mode parameter is wrong \n
*         -7: Interrupt parameter is wrong \n
*         -8: Interrupt function not initialised. See function "i_PCI3009_SetBoardIntRoutineX"
*/

_INT_    i_PCI3009_InitIndex    (DWORD_ dw_BoardHandle,
                                 BYTE_   b_ReferenceAction,
                                 BYTE_   b_IndexOperation,
                                 BYTE_   b_AutoMode,
                                 BYTE_   b_InterruptEnable);


/*i_PCI3009_EnableIndex*/
/** Enable the INDEX actions
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Index not initialised see function "i_PCI3009_InitIndex"
*/

_INT_    i_PCI3009_EnableIndex  (DWORD_ dw_BoardHandle);


/*i_PCI3009_DisableIndex*/
/** Disable the INDEX actions
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Index not initialised see function "i_PCI3009_InitIndex"
*/

_INT_    i_PCI3009_DisableIndex (DWORD_ dw_BoardHandle);


/*i_PCI3009_GetIndexStatus*/
/** Return the index status
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_IndexStatus   : 0 : No INDEX occur \n
*                                1 : A INDEX occur
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Index not initialised see function "i_PCI3009_InitIndex"
*/

_INT_    i_PCI3009_GetIndexStatus      (DWORD_ dw_BoardHandle,
                                        PBYTE_ pb_IndexStatus);



/*i_PCI3009_SetIndexAndReferenceSource*/
/** Determine the hardware source for the index and the \n
* reference logic. Per default the index logic is  \n
* connected to the difference input C and the reference  \n
* logic is connected to the 24V input E 
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_SourceSelection : PCI3009_SOURCE_0 : \n
*                                The index logic is connected to the difference input C and \n
*                                the reference logic is connected to the 24V input E. \n
*                                This is the default configuration. \n
*                                PCI3009_SOURCE_1 : \n
*                                The reference logic is connected to the difference \n
*                                input C and the index logic is connected to the 24V input E
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: The source selection is wrong
*/

_INT_    i_PCI3009_SetIndexAndReferenceSource   (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_SourceSelection);


/*i_PCI3009_InitReference*/
/** Initialise the reference.
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_ReferenceLevel  : Reference level. \n
*                                PCI3009_LOW  : Reference occur if "0" \n
*                                PCI3009_HIGH : Reference occur if "1"
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Reference level parameter is wrong
*/

_INT_    i_PCI3009_InitReference        (DWORD_ dw_BoardHandle,
                                         BYTE_   b_ReferenceLevel);


/*i_PCI3009_GetReferenceStatus*/
/** Return the reference status
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @param[out] pb_ReferenceStatus   : 0 : No REFERENCE occur \n
*                                    1 : A REFERENCE occur
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Reference not initialised see function "i_PCI3009_InitReference"
*/

_INT_    i_PCI3009_GetReferenceStatus      (DWORD_ dw_BoardHandle,
                                            PBYTE_ pb_ReferenceStatus);


/* @} */

/** \defgroup PCI3009_INC_CPT_UAS PCI-3009 incremental counter UAS,CBx,U/D#, external strobe functions
* \ingroup PCI3009_INC_CPT
* @{
*/


/*i_PCI3009_GetUASStatus*/
/** Return the error signal (UAS) status
*
* @param[in] dw_BoardHandle     : Handle of board PCI-3009
*
* @param[out] pb_UASStatus      : 0 : UAS is low "0" \n
*                                 1 : UAS is high "1"
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_GetUASStatus (DWORD_ dw_BoardHandle,
                                 PBYTE_ pb_UASStatus);


/*i_PCI3009_GetCBStatus*/
/** Return the counter overflow status
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_CBStatus      : 0 : Counter no overflow \n
*                                1 : Counter overflow
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_GetCBStatus  (DWORD_ dw_BoardHandle,
                                 PBYTE_ pb_CBStatus);


/*i_PCI3009_Get16BitCBStatus*/
/** Returns the counter overflow (counter initialised to 2*16-bit) status from selected incremental counter module
*
* @param[in] dw_BoardHandle       : Handle of board PCI-3009
*
* @param[out] pb_CBStatusCounter0 : 0 : No overflow occur for the first 16-bit counter \n
*                                   1 : Overflow occur for the first 16-bit counter
* @param[out] pb_CBStatusCounter1 : 0 : No overflow occur for the second 16-bit counter \n
*                                   1 : Overflow occur for the second 16-bit counter
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Counter not initialised to 2*16-bit mode. See function "i_PCI3009_InitCounter" \n
*         -5: Firmware revision error
*/

_INT_    i_PCI3009_Get16BitCBStatus     (DWORD_ dw_BoardHandle,
                                         PBYTE_ pb_CBStatusCounter0,
                                         PBYTE_ pb_CBStatusCounter1);


/*i_PCI3009_GetUDStatus*/
/** Return the counter progress status
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_UDStatus      : 0 : Counter progress in the selected mode down \n
*                                1 : Counter progress in the selected mode up \n
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_GetUDStatus  (DWORD_ dw_BoardHandle,
                                 PBYTE_ pb_UDStatus);


/*i_PCI3009_GetInterruptUDLatchedStatus*/
/** Return the counter progress latched status after a index interrupt occur.
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
*
* @param[out] pb_UDStatus      : 0 : Index occor. Counter progress in the selected mode down \n
*                                1 : Index occor. Counter progress in the selected mode up \n
*                                2 : No index interrupt occur
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Interrupt function not initialised.See function "i_PCI3009_SetBoardIntRoutine"
*/

_INT_    i_PCI3009_GetInterruptUDLatchedStatus  (DWORD_ dw_BoardHandle,
                                                 PBYTE_ pb_UDStatus);


/*i_PCI3009_InitExternalStrobe*/
/** Initialises the external strobe level.
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
* @param[in] b_ExternalStrobe      : External strobe selection \n
*                                       0 : External strobe A \n
*                                       1 : External strobe B
* @param[in] b_ExternalStrobeLevel : External strobe level \n
*                                       PCI3009_LOW  : External latch occurs if "0" \n
*                                       PCI3009_HIGH : External latch occurs if "1"
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: External strobe selection is wrong \n
*         -5: External strobe level parameter is wrong

*/

_INT_    i_PCI3009_InitExternalStrobe   (DWORD_ dw_BoardHandle,
                                         BYTE_   b_ExternalStrobe,
                                         BYTE_   b_ExternalStrobeLevel);


/* @} */

/** \defgroup PCI3009_INC_CPT_COMPARE PCI-3009 incremental counter compare functions
* \ingroup PCI3009_INC_CPT
* @{
*/


/*i_PCI3009_InitCompareLogic*/
/** Set the 32-Bit compare value. At that moment that the incremental counter arrive to the compare value \n
* (dw_CompareValue) a interrupt is generated.
*
* @param[in] dw_BoardHandle     : Handle of board PCI-3009
* @param[in] dw_CompareValue   : 32-Bit compare value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_InitCompareLogic     (DWORD_ dw_BoardHandle,
                                         DWORD_ dw_CompareValue);


/*i_PCI3009_EnableCompareLogic*/
/** Enable the 32-Bit compare logic. At that moment that the incremental counter arrive to the compare value a \n
* interrupt is generated. 
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Compare logic not initialised.See function "i_PCI3009_InitCompareLogic" \n
*         -5: Interrupt function not initialised.See function "i_PCI3009_SetBoardIntRoutineX"
*/

_INT_    i_PCI3009_EnableCompareLogic   (DWORD_ dw_BoardHandle);


/*i_PCI3009_DisableCompareLogic*/
/** Disable the 32-Bit compare logic.
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Compare logic not initialised. See function "i_PCI3009_InitCompareLogic"
*/

_INT_    i_PCI3009_DisableCompareLogic  (DWORD_ dw_BoardHandle);


/* @} */

/** \defgroup PCI3009_INC_CPT_FREQ PCI-3009 incremental counter frequency measurement functions
* \ingroup PCI3009_INC_CPT
* @{
*/


/*i_PCI3009_InitFrequencyMeasurement*/
/** Sets the time for the frequency measurement.\n
* Configures the selected TOR incremental counter. \n
* The dw_TimingInterval and ul_TimingUnity determine the time base for the measurement. \n
* The pdw_RealTimingInterval returns the real time value. You must call up this function before \n
* you call up any other function which gives access to the frequency measurement.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] b_TimingUnity    : Base time unit (0 to 2) \n
*                                  0 : ns \n
*                                  1 : s \n
*                                  2 : ms
* @param[in] dw_TimingInterval: Base time value.
*
* @param[out] pdw_RealTimingInterval : Real base time value.
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Timing unity selection is wrong \n
*         -5: Base timing selection is wrong
*/

_INT_    i_PCI3009_InitFrequencyMeasurement     (DWORD_   dw_BoardHandle,
                                                 BYTE_     b_TimingUnity,
                                                 DWORD_   dw_TimingInterval,
                                                 PDWORD_ pdw_RealTimingInterval);


/*i_PCI3009_EnableFrequencyMeasurement*/
/** Enables the frequency measurement function
*
* @param[in] dw_BoardHandle    : Handle of board PCI-3009
* @param[in] b_InterruptEnable : Enable or disable the interrupt. \n
*                                   PCI3009_ENABLE : Enable the interrupt \n
*                                   PCI3009_DISABLE: Disable the interrupt 
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Frequency measurement logic not initialised. See function "i_PCI3009_InitFrequencyMeasurement" \n
*         -5: Interrupt parameter is wrong \n
*         -6: Interrupt function not initialised. \n
*/

_INT_    i_PCI3009_EnableFrequencyMeasurement   (DWORD_ dw_BoardHandle,
                                                 BYTE_   b_InterruptEnable);


/*i_PCI3009_ReadFrequencyMeasurement*/
/** Returns the status (pb_Status) and the number of increments in the set time.\n
* See function "i_PCI3009_InitFrequencyMeasurement"
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @param[out] pb_Status     : Returns the frequency measurement status \n
*                                0 : Counting cycle not started. \n
*                                1 : Counting cycle started. \n
*                                2 : Counting cycle stopped. The measurement cycle is completed.
* @param[out] pb_UDStatus      : 0 : Counter progress in the selected mode down \n
*                                1 : Counter progress in the selected mode up 
* @param[out] pdw_ReadValue   : Return the number of increments in the defined time base.
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Frequency measurement logic not initialised. See function "i_PCI3009_InitFrequencyMeasurement"
*/

_INT_    i_PCI3009_ReadFrequencyMeasurement (DWORD_     dw_BoardHandle,
                                             PBYTE_     pb_Status,
                                             PBYTE_     pb_UDStatus,
                                             PDWORD_    pdw_ReadValue);


/*i_PCI3009_DisableFrequencyMeasurement*/
/** Disables the frequency measurement function
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter" \n
*         -4: Frequency measurement logic not initialised. See function "i_PCI3009_InitFrequencyMeasurement"
*/

_INT_    i_PCI3009_DisableFrequencyMeasurement  (DWORD_ dw_BoardHandle);


/* @} */

/** \defgroup PCI3009_INC_CPT_DIG_OUT PCI-3009 incremental counter digital output functions
* \ingroup PCI3009_INC_CPT
* @{
*/

/*i_PCI3009_SetDigitalChlOn*/
/** Sets the digital output H Setting an output means setting an ouput high. 
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_SetDigitalChlOn (DWORD_ dw_BoardHandle);


/*i_PCI3009_SetDigitalChlOff*/
/** Resets the digital output H. Resetting an output means setting an ouput low.
*
* @param[in] dw_BoardHandle        : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a counter module \n
*         -3: Counter not initialised see function "i_PCI3009_InitCounter"
*/

_INT_    i_PCI3009_SetDigitalChlOff (DWORD_ dw_BoardHandle);


/* @} */



/* @} */

/** \defgroup PCI3009_CHRONOS PCI-3009 chronos functions
* \ingroup PCI3009_MODULE
* @{
*/

/** \defgroup PCI3009_CHRONOS_INIT PCI-3009 Chronos initialisation functions
* \ingroup PCI3009_CHRONOS
* @{
*/

/*i_PCI3009_InitChrono*/
/** Configure the chronometer operating mode (b_ChronoMode) \n
* The dw_TimingInterval and dw_TimingUnit determine the timing base for the measurement. \n
* The pdw_RealTimingInterval return the real timing value.  \n
* You must calling this function be for you call any other function witch access of the chronometer. \n \n
*
* Witch this functionality from the xPCI-3009 you have the possibility to measure the timing witch two event. \n \n
*
* The mode 0 and 1 is appropriate for period measurement. \n
* The mode 2 and 3 is appropriate for frequent measurement.  \n
* The mode 4 to 7 is appropriate for measuring the timing between two events.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in]  b_ChronoMode   : Chronometer action mode (0 to 7).\n\n
* <table>
*    <tr>
*       <td>Mode</td>
*       <td>Function of signal C</td>
*       <td>Function of signal D</td>
*    </tr>
*    <tr>
*       <td>0</td>
*       <td>The high level starts the time measuring.\n The low level stopsthe time measuring.</td>
*       <td>Not used</td>
*    </tr>
*    <tr>
*       <td>1</td>
*       <td>The low level starts the time measuring.\n The high level stopsthe time measuring.</td>
*       <td>Not used</td>
*    </tr>
*    <tr>
*       <td>2</td>
*       <td>The high level starts the time measuring.\n The next high level stops the time measuring.</td>
*       <td>Not used</td>
*    </tr>
*    <tr>
*       <td>3</td>
*       <td>The low level starts the time measuring.\n The next low level stops the time measuring.</td>
*       <td>Not used</td>
*    </tr>
*    <tr>
*       <td>4</td>
*       <td>The high level starts the time measuring.</td>
*       <td>The high level stops the time measuring.</td>
*    </tr>
*    <tr>
*       <td>5</td>
*       <td>The low level starts the time measuring.</td>
*       <td>The low level stops the time measuring.</td>
*    </tr>
*    <tr>
*       <td>6</td>
*       <td>The high level starts the time measuring.</td>
*       <td>The low level stops the time measuring.</td>
*    </tr>
*    <tr>
*       <td>6</td>
*       <td>The low level starts the time measuring.</td>
*       <td>The high level stops the time measuring.</td>
*    </tr>
* </table>\n
* @param[in]  b_TimingUnit   : Base timing unity (0 to 4) \n 
*                                                 0 : ns \n
*                                                 1 : s \n
*                                                 2 : ms \n
*                                                 3 : s  \n
*                                                 4 : mn
* @param[in]  dw_TimingInterval : Base timing value.\n\n
*
* <table>
*    <tr>
*       <td>b_TimeUnit</td>
*       <td>dw_TimeInterval min vale</td>
*       <td>dw_TimeInterval min vale</td>
*    </tr>
*    <tr>
*       <td>0 (ns)</td>
*       <td>50</td>
*       <td>4294967295</td>
*    </tr>
*    <tr>
*       <td>1 (micro s)</td>
*       <td>1</td>
*       <td>107374182</td>
*    </tr>
*    <tr>
*       <td>2 (ms)</td>
*       <td>1</td>
*       <td>107374</td>
*    </tr>
*    <tr>
*       <td>3 (s)</td>
*       <td>1</td>
*       <td>107</td>
*    </tr>
*    <tr>
*       <td>4 (mn)</td>
*       <td>1</td>
*       <td>2</td>
*    </tr>
* </table>\n
*
* @param[out]  pdw_RealTimingInterval : Real  base timing value.
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module \n
*         -3: Chronometer mode selection is wrong \n
*         -4: Timing unity selection is wrong \n
*         -5: Base timing selection is wrong
*/
_INT_   i_PCI3009_InitChrono   (DWORD_   dw_BoardHandle,
				                BYTE_     b_ChronoMode,
				                BYTE_     b_TimingUnit,
				                DWORD_   dw_TimingInterval,
				                PDWORD_ pdw_RealTimingInterval);


/*i_PCI3009_EnableChrono*/
/** Enable the chronometer. You must calling the "i_PCI3009_InitChrono" function be for you call this function. \n
* If you enable the chronometer interrupt, the chronometer generate a interrupt after the stop signal.\n
* See function "i_PCI3009_SetBoardIntRoutine" and the Interrupt mask description chapter from this manual. \n
* The b_CycleMode parameter determine if you will measured a single or more cycle.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
* @param[in]  b_CycleMode    : Selected the chronometer acquisition mode \n
*                              PCI3009_SINGLE : Single acquisition \n
*                              PCI3009_CONTINUOUS : Continuous acquisition
* @param[in]  b_InterruptEnable : PCI3009_ENABLE: \n
*                                 Enable the chronometer interrupt \n
*                                 PCI3009_DISABLE: \n
*                                 Disable the chronometer interrupt
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" \n
*         -4: Chronometer acquisition mode cycle is wrong  \n
*         -5: Interrupt parameter is wrong  n
*         -6: Interrupt function not initialised. See function "i_PCI3009_SetBoardIntRoutine"
*/
_INT_   i_PCI3009_EnableChrono (DWORD_ dw_BoardHandle,
				                BYTE_   b_CycleMode,
				                BYTE_   b_InterruptEnable);


/*i_PCI3009_DisableChrono*/
/** Disable the chronometer. If you disable the chronometer after a start signal occur and you restart the chronometer \n
* witch the " i_PCI3009_EnableChrono" function, if no stop signal occur this start signal is ignored.
*
* @param[in] dw_BoardHandle  : Handle of board PCI-3009
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono"
*/
_INT_   i_PCI3009_DisableChrono        (DWORD_ dw_BoardHandle);

/* @} */

/** \defgroup PCI3009_CHRONOS_READ PCI-3009 Chronos read functions
* \ingroup PCI3009_CHRONOS
* @{
*/


/*i_PCI3009_GetChronoProgressStatus*/
/** Return the chronometer status (pb_ChronoStatus) from chronometer module
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
*
* @param[out] pb_ChronoStatus : Return the chronometer status. \n
*                               0 : Measurement not started. No start signal occur. \n
*                               1 : Measurement started. A start signal occur. \n
*                               2 : Measurement stopped. A stop signal occur. The measurement is terminate. \n
*                               3 : A overflow occur. You must change the base timing witch the function "i_PCI3009_InitChrono"
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" 
*/
_INT_   i_PCI3009_GetChronoProgressStatus      (DWORD_ dw_BoardHandle,
						                        PBYTE_ pb_ChronoStatus);


/*i_PCI3009_ReadChronoValue*/
/** Return the chronometer status (pb_ChronoStatus) and thetiming value (pdw_ChronoValue) after a stop signal occur. \n
* This function are only avaible if you have disabled the interrupt functionality. See function "i_PCI3009_EnableChrono". \n\n
*
* The returned value from pdw_ChronoValue parameter is not real measured timing. \n
* You must used the "i_PCI3009_ConvertChronoValue" function or make this operation for calculate the timing: \n
* Timing = pdw_ChronoValue * pdw_RealTimingInterval.\n
*
* pdw_RealTimingInterval is the returned parameter from "i_PCI3009_InitChrono" function and the time unity is the b_TimingUnit from "i_PCI3009_InitChrono" function.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] dw_TimeOut       : Read time out (ms) \n
*                                0: Disabled \n
*                                < 65536: Enabled
*
* @param[out] pb_ChronoStatus : Return the chronometer status. \n
*                               0 : Measurement not started. No start signal occur. \n
*                               1 : Measurement started. A start signal occur. \n
*                               2 : Measurement stopped. A stop signal occur. The measurement is terminate. \n
*                               3 : A overflow occur. You must change the base timing witch the function "i_PCI3009_InitChrono" \n
*                               4 : Time out occur
* @param[out] pdw_ChronoValue : Chronometer timing value
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" \n
*         -4: Timeout parameter is wrong (0 to 65535) 
*/
_INT_   i_PCI3009_ReadChronoValue      (DWORD_   dw_BoardHandle,
					                    DWORD_   dw_TimeOut,
					                    PBYTE_   pb_ChronoStatus,
					                    PDWORD_ pdw_ChronoValue);


/*i_PCI3009_ConvertChronoValue*/
/** Convert the chronometer measured timing (dw_ChronoValue) in to h, mn, s, ms, s, ns.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in] dw_ChronoValue   : Measured chronometer timing value. See"i_PCI3009_ReadChronoValue"
*
* @param[out]  pdw_Hour       : Chronometer timing hour
* @param[out]  pb_Minute      : Chronometer timing minute
* @param[out]  pb_Second      : Chronometer timing second
* @param[out] pdw_MilliSecond : Chronometer timing mini second
* @param[out] pdw_MicroSecond : Chronometer timing micro second 
* @param[out] pdw_NanoSecond  : Chronometer timing nano second
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono"
*/
_INT_ i_PCI3009_ConvertChronoValue     (DWORD_   dw_BoardHandle,
					                    DWORD_   dw_ChronoValue,
					                    PDWORD_ pdw_Hour,
					                    PBYTE_   pb_Minute,
					                    PBYTE_   pb_Second,
					                    PDWORD_  pdw_MilliSecond,
					                    PDWORD_  pdw_MicroSecond,
					                    PDWORD_  pdw_NanoSecond);

/* @} */

/** \defgroup PCI3009_CHRONOS_DIG_OUT PCI-3009 Chronos digital output functions
* \ingroup PCI3009_CHRONOS
* @{
*/

/*i_PCI3009_SetChronoChlOn*/
/** Sets the output witch has been passed with the parameter b_Channel. Setting an output means setting an output high.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_OutputChannel : Selection from digital output channel (0 to 2) \n
*                                   0 : Channel H \n
*                                   1 : Channel A \n
*                                   2 : Channel B 
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" \n
*         -4: The selected digital output is wrong
*/
_INT_   i_PCI3009_SetChronoChlOn       (DWORD_ dw_BoardHandle,
					                    BYTE_   b_OutputChannel);

/*i_PCI3009_SetChronoChlOff*/
/** Resets the output witch has been passed with the parameter b_Channel. Reseting an output means setting an output low.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_OutputChannel : Selection from digital output channel (0 to 2) \n
*                                   0 : Channel H \n
*                                   1 : Channel A \n
*                                   2 : Channel B 
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" \n
*         -4: The selected digital output is wrong
*/
_INT_   i_PCI3009_SetChronoChlOff      (DWORD_ dw_BoardHandle,
					                    BYTE_   b_OutputChannel);

/* @} */


/** \defgroup PCI3009_CHRONOS_DIG_INP PCI-3009 Chronos digital input functions
* \ingroup PCI3009_CHRONOS
* @{
*/

/*i_PCI3009_ReadChronoChlValue*/
/** Return the status from selected digital input (b_InputChannel) from chronometer module.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
* @param[in]  b_InputChannel  : Selection from digital inout channel (0 to 2) \n
*                                   0 : Channel E \n
*                                   1 : Channel F \n
*                                   2 : Channel G 
*
* @param[out] pb_ChannelStatus : Digital input channel status.\n
*                                  0 : Channel is not active \n
*                                  1 : Channel is active 
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono" \n
*         -4: The selected digital input is wrong
*/
_INT_   i_PCI3009_ReadChronoChlValue   (DWORD_ dw_BoardHandle,
					                    BYTE_   b_InputChannel,
					                    PBYTE_ pb_ChannelStatus);

/*i_PCI3009_ReadChronoPortValue*/
/** Return the status from digital inputs port from chronometer module.
*
* @param[in] dw_BoardHandle   : Handle of board PCI-3009
*
* @param[out] pb_PortValue    : Digital input port status.\n
*                                  D0 : 0 : Channel E is low / 1 : Channel E is high \n
*                                  D1 : 0 : Channel F is low / 1 : Channel F is high \n
*                                  D2 : 0 : Channel G is low / 1 : Channel G is high
*
* @return  0: No error \n
*         -1: The handle parameter of the board is wrong \n
*         -2: The module is not a Chronometer module  \n
*         -3: Chronometer not initialised see function "i_PCI3009_InitChrono"
*/
_INT_   i_PCI3009_ReadChronoPortValue  (DWORD_ dw_BoardHandle,
					                    PBYTE_ pb_PortValue);

/* @} */

/* @} */


/* @} */

#endif
