/** @file Utils.c
 *
 *  @authors S. Beuque, J. Krauth, L. Sartory
 *  @date    Creation: 25.04.2016
 *  @date    $LastChangedDate: 2013-02-01 15:02:09 +0100 (Fr, 01 Feb 2013) $
 *  @version $LastChangedRevision: 3764 $
 *
 *  @par DESCRIPTION
 *  Miscellaneous sample utilities 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2016 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
#include "Utils.h"

LONGLONG ll_Utils_ReadInteger(LONGLONG l_MinValue, LONGLONG l_MaxValue, PCHAR pc_Description, ...);

char *getModuleConfiguration(DWORD moduleConfiguration)
{
    moduleConfiguration = ((moduleConfiguration >> 16) & 0xFFFF);
    if (moduleConfiguration == 0x5343)
        return "Incremental counter";
    else if (moduleConfiguration == 0x5349)
        return "SSI";
    else if (moduleConfiguration == 0x4449)
        return "Digital IO";
    else if (moduleConfiguration == 0x4348)
        return "Chronometer";
    else
        return "Unknown module";
}

/**
*  Helper function, used to open a specific board
**/
_INT_ i_Utils_OpenBoard(DWORD *pdw_BoardHandle)
{
	INT   ret;
	DWORD version;
	BYTE  boardNbr;
	BYTE  i;

	if (i_PCI3009_GetDLLVersion(&version) == 0)
		printf("DLL version: \t\t%04x-%04x\n", (version >> 16) & 0xFFFF, version & 0xFFFF);

	ret = i_PCI3009_GetNumberOfBoards(&boardNbr);
	if (ret != 0)
	{
		fprintf(stderr, "i_PCI3009_GetNumberOfBoards failed: %d\n", ret);
		return ret;
	}

	printf("%d board%s found.\n\n", boardNbr, boardNbr > 1 ? "s were" : " was");
	if (boardNbr < 1)
		return -1;

	for (i = 0; i < boardNbr; i++)
	{
		CHAR  identifier[50];
		DWORD uiNumber;
		DWORD deviceNumber;
		DWORD busNumber;
		DWORD baseAddress[4];
		DWORD moduleConfiguration;
		DWORD revision;
		BYTE  interrupt;

		ret = i_PCI3009_GetBoardInformation(i,
											sizeof(identifier),
											identifier,
											&uiNumber,
											&deviceNumber,
											&busNumber,
											&baseAddress[0],
											&baseAddress[1],
											&baseAddress[2],
											&baseAddress[3],
											&interrupt,
											&moduleConfiguration,
											&revision);
		if (ret != 0)
		{
			fprintf(stderr, "i_PCI3009_GetBoardInformation failed for board %d: %d\n", i, ret);
			continue;
		}

		printf("Board index: \t\t%d\n", i);
		printf("Identifier: \t\t%s\n", identifier);
		printf("Base address 0: \t0x%X\n", baseAddress[0]);
		printf("Base address 1: \t0x%X\n", baseAddress[1]);
		printf("Base address 2: \t0x%X\n", baseAddress[2]);
		printf("Base address 3: \t0x%X\n", baseAddress[3]);
		printf("UI number: \t\t%d\n", uiNumber);
		printf("Device number: \t\t%d\n", deviceNumber);
		printf("Bus number: \t\t%d\n", busNumber);
		printf("Interrupt line: \t%d\n", interrupt);
		printf("Module configuration \t%s version : %c%c\n", getModuleConfiguration(moduleConfiguration), (moduleConfiguration >> 8) & 0xFF, moduleConfiguration & 0xFF);
		printf("Revision : \t\t%c%c%c%c", (char)((revision >> 24) & 0xFF), (char)((revision >> 16) & 0xFF), (char)((revision >> 8) & 0xFF), (char)(revision & 0xFF)); 

		printf("\n");	}

	if (ll_Utils_ReadInteger(0, 1, "Should the board be opened via index (0) or via identifier (1)?") == 0)
	{
		ret = i_PCI3009_OpenBoardViaIndex((BYTE)ll_Utils_ReadInteger(0, boardNbr - 1, "Enter the index of the board (0 to %d):", boardNbr - 1), pdw_BoardHandle);
		if (ret != 0)
		{
			fprintf(stderr, "i_PCI3009_OpenBoardViaIndex failed: %d\n", ret);
			return ret;
		}
	}
	else
	{
		CHAR identifier[50];
		printf("Enter the board identifier: ");
		scanf_s("%s", identifier);
		ret = i_PCI3009_OpenBoardViaIdentifer(identifier, pdw_BoardHandle);
		if (ret != 0)
		{
			fprintf(stderr, "i_PCI3009_OpenBoardViaIdentifier failed: %d\n", ret);
			return ret;
		}
	}

	if (i_PCI3009_GetDeviceDriverVersion(*pdw_BoardHandle, &version) == 0)
		printf("Device driver version: \t%04x-%04x\n", (version >> 16) & 0xFFFF, version & 0xFFFF);
	printf("\n");

	return ret;
}

/**
*  Prompts the user to enter a value within specified bounds
**/
LONGLONG ll_Utils_ReadInteger(LONGLONG l_MinValue, LONGLONG l_MaxValue, PCHAR pc_Description, ...)
{
	va_list args;
	LONGLONG readValue;

	va_start(args, pc_Description);
	do
	{
		vfprintf(stdout, pc_Description, args);
		fprintf(stdout, " ");
		fflush(stdout);
		scanf_s("%llu", &readValue);
	}
	while (readValue < l_MinValue || readValue > l_MaxValue);
	va_end(args);
	return readValue;
}

/**
*  Display a sort of progress bar
**/
_VOID_ v_Utils_DisplayRunningStatus()
{
	static int charNbr = 0;
	int i = 0;

	for (i = 0; i < 5; i++)
		printf(i < charNbr ? "." : " ");
	printf("\r");

	charNbr = (charNbr + 1) % 5;
}