using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PCI3009_NET;

namespace TimerCounterWatchdog
{
    public partial class TimerCounterWatchdog : Form
    {
        /// <summary>
        /// Handle to the first board
        /// </summary>
        private PCI3009_NET.cl_PCI3009 _board;

        int[] interruptCounter = new int[3];

        public enum Functionality
        {
            WATCHDOG = 0x0, //0
            TIMER = 0x4010, //16400
            UP_COUNTER = 0xE0000, //917504
            DOWN_COUNTER = 0xA0000 //655360
        }
        public enum Output
        {
            SET_LOW = 0x1000, //4096
            SET_HIGH = 0x800, //2048
            FLIP_FLOP = 0x2800 //10240
        }
        /// <summary>
        /// Constructor of the form
        /// </summary>
        public TimerCounterWatchdog()
        {
            InitializeComponent();
        }
        public void v_Interrupt(object sender, PCI3009_NET.cl_PCI3009.cl_EventHandlerArgs e)
        {
            /* Counter, Timer, Watchdog interrupt */
            if (e.dw_InterruptSrc == 4)
            {
                if ((e.dw_InterruptMask & 0x3) != 0)
                /* Timer/Counter 0 interrupt */
                    interruptCounter[0]++;

                /* Timer/Counter/Watchdog 1 interrupt */
                else if ((e.dw_InterruptMask & 0x38) != 0)
                    interruptCounter[1]++;

                /* Timer/Counter/Watchdog 1 interrupt */
                else if ((e.dw_InterruptMask & 0x1C0) != 0)
                    interruptCounter[2]++;
            }
        }
        /// <summary>
        /// Called at the first load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timerCounterWatchdogInterrupt_Load(object sender, EventArgs e)
        { 
            _board = new cl_PCI3009();
            try
            {
                int returnValue = _board.i_OpenBoardViaIndex(0);
                if (returnValue != 0)
                    throw new Exception("i_OpenBoardViaIndex board index 0: error = " + returnValue.ToString());
                _board.e_EventHandlerDelegate += new cl_PCI3009.v_EventHandlerDelegate(v_Interrupt);
                _board.b_EventHandlerInitialised = 1;

                //ComboBox initialisation 
                timerCounterWatchdogComboBox.SelectedIndex = 0;
                modeComboBox.SelectedIndex = 1;
                timeBaseComboBox.SelectedIndex = 0;
                outputActionComboBox.SelectedIndex = 0; 
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                Close();
            }
        }
        private long getEnumValue<T>(int index)
        {
            return (long)Convert.ChangeType(((T[])Enum.GetValues(typeof(T)))[index], typeof(long));
        }
        private void startButton_Click(object sender, EventArgs e)
        {
            int returnValue = 0;
            byte[] channelList = new byte[4] {0, 1, 2, 3};
            byte channel = 0;
            int[] analogValue = new int[4] {4095, 4095, 4095, 4095};
            try
            {
                if (interruptCheckBox.Checked)
                {
                    interruptCounter[0] = 0;
                    interruptCounter[1] = 0;
                    interruptCounter[2] = 0;
                    //Enable the interruption
                    returnValue = _board.i_SetBoardIntRoutine();
                    if (returnValue != 0)
                        throw new Exception("i_SetBoardIntRoutine: Error = " + returnValue.ToString());
                }
                if (((timerCounterWatchdogComboBox.SelectedIndex == 2) || (timerCounterWatchdogComboBox.SelectedIndex == 1)) && (modeComboBox.SelectedIndex == 0))
                {
                    if (timerCounterWatchdogComboBox.SelectedIndex == 1)
                    {
                        if(singleRadioButton.Checked)
                        {
                            returnValue = _board.i_AnalogInputInitMode(PCI3009_NET.cl_PCI3009.PCI3009_SINGLE);
                            if (returnValue != 0)
                                throw new Exception("i_AnalogInputInitMode: Error = " + returnValue.ToString());

                            for (channel = 0; channel < 8; channel++)
                            {
                                returnValue = _board.i_AnalogInputInitChannel(channel, PCI3009_NET.cl_PCI3009.PCI3009_1_GAIN, PCI3009_NET.cl_PCI3009.PCI3009_UNIPOLAR);
                                if (returnValue != 0)
                                    throw new Exception("i_AnalogInputInitChannel: Error = " + returnValue.ToString());
                            }  
                        }
                        else
                        {
                            returnValue = _board.i_AnalogInputInitMode(PCI3009_NET.cl_PCI3009.PCI3009_DIFF);
                            if (returnValue != 0)
                                throw new Exception("i_AnalogInputInitMode: Error = " + returnValue.ToString());

                            for (channel = 0; channel < 4; channel++)
                            {
                                returnValue = _board.i_AnalogInputInitChannel(channel, PCI3009_NET.cl_PCI3009.PCI3009_1_GAIN, PCI3009_NET.cl_PCI3009.PCI3009_BIPOLAR);
                                if (returnValue != 0)
                                    throw new Exception("i_AnalogInputInitChannel: Error = " + returnValue.ToString());
                            }  
                        }
                        returnValue = _board.i_AnalogOutputWriteMoreChannels(4, channelList, analogValue);
                        if (returnValue != 0)
                            throw new Exception("i_AnalogOutputWriteMoreChannels: Error = " + returnValue.ToString());
                    }
                    else  
                    {
                        returnValue = _board.i_DigitalOutputWriteAll(15);
                        if (returnValue != 0)
                            throw new Exception("i_DigitalOutputWriteAll: Error = " + returnValue.ToString());

                        digitalOutputsLabel.Enabled = true;
                        timerDigitalOutputsLabel.Enabled = true;
                    }
                }
                if ((timerCounterWatchdogComboBox.SelectedIndex == 0) && (modeComboBox.SelectedIndex == 0))
                    throw new Exception("startButton_Click: Error = You can't use the watchdog with index 0");

                if ((outputActionComboBox.SelectedIndex == 2) && (outputActionComboBox.SelectedIndex == 0))
                    throw new Exception("startButton_Click: Error = If the watchdog is selected, the FLIP_FLOP output action can't be used");

                returnValue = _board.i_TmrCptWatInit((byte)timerCounterWatchdogComboBox.SelectedIndex,
                                                        getEnumValue<Functionality>(modeComboBox.SelectedIndex), 
                                                        Convert.ToUInt32(reloadValueUP.Value),
                                                        (byte)((timeBaseComboBox.SelectedIndex) + 1),
                                                        getEnumValue<Output>(outputActionComboBox.SelectedIndex), 
                                                        (byte)((interruptCheckBox.Checked) ? 1 : 0));
                if (returnValue != 0)
                    throw new Exception("i_TmrCptWatInit: Error = " + returnValue.ToString());
                
                returnValue = _board.i_TmrCptWatEnable((byte)timerCounterWatchdogComboBox.SelectedIndex);
                if (returnValue != 0)
                    throw new Exception("i_TmrCptWatEnable: Error = " + returnValue.ToString());

                timerDisplayTimer.Start();
                initGroupBox.Enabled = false;
                startButton.Enabled = false;
                stopButton.Enabled = true;
                triggerButton.Enabled = true;
            }
            catch(Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void timerDisplayTimer_Tick(object sender, EventArgs e)
        {
            int returnValue = 0;
            long value = 0;
            byte downStatus = 0;
            byte triggerStatus = 0;
            byte outputState = 0;
            byte status = 0;
            try
            {
                if ((timerCounterWatchdogComboBox.SelectedIndex == 2) && (modeComboBox.SelectedIndex == 0))
                {
                    returnValue = _board.i_DigitalOutputReadAll(ref status);
                    if (returnValue != 0)
                    throw new Exception("i_DigitalOutputReadAll: Error = " + returnValue.ToString());
                }
                returnValue = _board.i_TmrCptWatGetStatus((byte)timerCounterWatchdogComboBox.SelectedIndex, 
                                                              ref value, 
                                                              ref downStatus,
                                                              ref triggerStatus,
                                                              ref outputState);
                if (returnValue != 0)
                    throw new Exception("i_TmrCptWatGetStatus: Error = " + returnValue.ToString());

                timerValueLabel.Text = value.ToString();
                timerDownStatusLabel.Text = downStatus.ToString();
                timerTriggerStateLabel.Text = triggerStatus.ToString();
                timerOutputStateLabel.Text = outputState.ToString();
                timerDigitalOutputsLabel.Text = status.ToString("X");
                timerInterruptCounterLabel.Text = interruptCounter[(timerCounterWatchdogComboBox.SelectedIndex)].ToString();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void stopButton_Click(object sender, EventArgs e)
        {
            initGroupBox.Enabled = true;
            startButton.Enabled = true;
            stopButton.Enabled = false;
            triggerButton.Enabled = false;
            int returnValue = 0;
            timerDisplayTimer.Stop();
            try
            {
                if (interruptCheckBox.Checked)
                {
                    returnValue = _board.i_ResetBoardIntRoutine();
                    if (returnValue != 0)
                        throw new Exception("i_ResetBoardIntRoutine: Error = " + returnValue.ToString());
                }
                returnValue = _board.i_TmrCptWatDisable((byte)timerCounterWatchdogComboBox.SelectedIndex);
                if (returnValue != 0)
                    throw new Exception("i_TmrCptWatDisable: Error = " + returnValue.ToString());
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        private void triggerButton_Click(object sender, EventArgs e)
        {
            try
            {
                int returnValue = _board.i_TmrCptWatTrigger((byte)timerCounterWatchdogComboBox.SelectedIndex);
                if (returnValue != 0)
                    throw new Exception("i_TmrCptWatTrigger: Error = " + returnValue.ToString());

                if ((timerCounterWatchdogComboBox.SelectedIndex == 2) && (modeComboBox.SelectedIndex == 0))
                {
                    returnValue = _board.i_DigitalOutputWriteAll(15);
                    if (returnValue != 0)
                        throw new Exception("i_DigitalOutputWriteAll: Error = " + returnValue.ToString());

                    digitalOutputsLabel.Enabled = true;
                    timerDigitalOutputsLabel.Enabled = true;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}